<?php

/*
Plugin Name: BigBuy Dropshipping Connector for WooCommerce
Plugin URI: http://www.bigbuy.eu/blog/en/bigbuy-plugin-woocommerce
Text Domain: WC-Mipconnector
Domain Path: /app/translations
Description: Sync the BigBuy catalog in your WooCommerce with our plugin
Version: 1.0.4
Author: BigBuy
Author URI: https://bigbuy.eu
*/

defined('ABSPATH') || exit;

require_once __DIR__.'/vendor/autoload.php';
require_once __DIR__.'/app/views/WcMipConnectorViewManager.php';

use WcMipConnector\Controller\ApiController;
use WcMipConnector\Manager\SystemManager;
use WcMipConnector\Enum\MipWcConnector;
use WcMipConnector\Service\ZoneService;
use WcMipConnector\Service\SystemService;

$classMipconnector = new WcMipconnector();
$apiController = new ApiController();
$wooCommerceViewManager = new WcMipConnectorViewManager();
$carrierService = new ZoneService();
$systemService = new SystemService();

register_activation_hook(__FILE__, array($classMipconnector,'installMipConnector'));
//register_deactivation_hook(__FILE__, array($classMipconnector,'uninstallMipConnector'));

add_action('admin_menu', array($wooCommerceViewManager, 'loadMenu'));
add_action('init', array($wooCommerceViewManager, 'loadTranslations'));
add_filter('woocommerce_package_rates', array($carrierService, 'shippingMethodsAvailable'), 10);
add_filter('woocommerce_cart_shipping_method_full_label', array($carrierService, 'modifyShippingLabel'), 10, 2);
add_filter('woocommerce_after_shipping_rate', array($carrierService, 'findDataToProcess'), 10, 3);
add_action('woocommerce_after_calculate_totals', array($carrierService, 'getTotalCart'), 10, 1);
add_action('woocommerce_email', array($systemService, 'updateSendOrderEmailConfiguration'));

class WcMipconnector
{
    /**
     * @throws Exception
     */
    public function installMipConnector(): void
    {
        if ((PHP_VERSION_ID < MipWcConnector::PHP_VERSION) || (get_bloginfo('version', 'display') < MipWcConnector::WP_VERSION) || (get_option('woocommerce_version') < MipWcConnector::WC_VERSION) || !function_exists('curl_init') || !extension_loaded('curl')) {
            return;
        }
        $systemManager = new SystemManager();
        $systemManager->installMipConnector();
    }

    public function uninstallMipConnector(): void
    {
        $systemManager = new SystemManager();
        $systemManager->uninstallMipConnector();
    }
}