<?php

defined('ABSPATH') || exit;

use WcMipConnector\Enum\MipWcConnector;
use WcMipConnector\Exception\WooCommerceApiConnectionException;
use WcMipConnector\Manager\LanguageReportManager;
use WcMipConnector\Manager\WoocommerceApiConnectionManager;
use WcMipConnector\Service\AccountInfoReportService;
use WcMipConnector\Manager\TagManager;
use WcMipConnector\Service\SystemService;
use WcMipConnector\Service\TaxesService;
use WcMipConnector\Service\ZoneService;

class WcMipConnectorViewManager
{
    private const BYTES_TO_MB = 1048576;
    private const RECOMMENDED_MEMORY_LIMIT = 1024;
    private const RECOMMENDED_MAX_EXECUTION_TIME = 3600;
    private const DEFAULT_CURRENCY = 'EUR';
    private const CRON_EVERY_MINUTE = '* * * * *';
    private const CRON_EVERY_DAY = '15 0 * * *';
    private const FLOCK_CRON = '/usr/bin/flock -n';
    private const CURL_CRON = '/usr/bin/curl';
    private const WOOCOMMERCE_CRON = '/tmp/wc_process_import.lockfile ';
    private const GOOGLE_SHOPPING_CRON = '/tmp/gs_process_import.lockfile';
    private const STATUS_OK = 'OK';
    private const TAXES_NOT_CONFIGURED = 'The taxes are not configured correctly';

    /**@var WoocommerceApiConnectionManager */
    protected $apiConnection;
    /**@var TagManager */
    protected $tagManager;
    /** @var ZoneService */
    protected $zoneService;
    /** @var string */
    protected $language;

    public function __construct()
    {
        $this->apiConnection = new WoocommerceApiConnectionManager();
        $this->tagManager = new TagManager();
        $this->zoneService = new ZoneService();
    }

    public function loadTranslations():void
    {
        load_plugin_textdomain('WC-Mipconnector', FALSE, MipWcConnector::TRANSLATIONS_DIR);
    }

    public function loadMenu():void
    {
        $page_title = 'BigBuy WC Dropshipping Connector';
        $menu_title = 'BigBuy';
        $capability = 'administrator';
        $menu_slug = 'bigbuy-wc-dropshipping-connector';
        $function = array($this, 'loadAccessAndSecretFormView');
        $icon_url = 'data:image/svg+xml;base64,'.base64_encode('<svg version="1.1" id="Capa_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
	 viewBox="0 0 20 20" style="enable-background:new 0 0 20 20;" xml:space="preserve">
<path style="fill:#FFFFFF;" d="M6.6,8.6c0-0.3-0.1-0.5-0.3-0.7C6.1,7.8,5.8,7.8,5.5,7.8H4.9l0.1,1.7h0.7c0.4,0,0.7-0.1,0.8-0.3
	C6.6,9.1,6.6,9,6.6,8.6z M16.4,1.8C16.4,1.8,16.5,1.8,16.4,1.8z M6,13.9c0.1-0.1,0.1-0.1,0.1-0.4c0-0.3-0.1-0.4-0.1-0.4
	C5.8,13,5.7,13,5.5,13H4.9l0.1,1h0.5C5.7,14,5.8,14,6,13.9z M16.4,2.1c0.1,0,0.1-0.1,0.1-0.1c0-0.1-0.1-0.1-0.1-0.1
	c-0.1,0-0.1,0.1-0.1,0.1L16.4,2.1z M16.4,1.8C16.4,1.8,16.5,1.8,16.4,1.8C16.5,1.8,16.5,1.8,16.4,1.8C16.5,1.8,16.5,1.8,16.4,1.8
	c0.1,0,0.1,0.1,0.1,0.1C16.4,1.9,16.4,1.9,16.4,1.8v0.3V1.8z M6,6c0.1-0.1,0.1-0.3,0.1-0.5c0-0.3-0.1-0.4-0.3-0.5
	C5.7,4.8,5.5,4.7,5.1,4.8H4.5l0.1,1.4h0.5C5.6,6.2,5.8,6.1,6,6z M5.7,15.3H5.2l0.1,1.3H6c0.1-0.1,0.3-0.1,0.4-0.3
	c0.1-0.1,0.1-0.3,0.1-0.5c0-0.3-0.1-0.4-0.3-0.4C6.1,15.3,6,15.3,5.7,15.3z M17.9,0.3L0.3,2.1l1.8,17.7l17.7-1.8L17.9,0.3z
	 M16.4,1.7c0.1,0,0.3,0.1,0.3,0.1c0,0.1-0.1,0.3-0.1,0.3c-0.1,0-0.3-0.1-0.3-0.1C16.2,1.8,16.2,1.7,16.4,1.7z M11.2,3.9
	c0-0.3,0-0.4,0.1-0.7c0.1-0.4,0.4-0.7,0.9-0.9c0.4-0.1,0.9-0.3,1.6-0.4c0.5,0,0.9,0,1.4,0c0.5,0,0.9,0.1,1.4,0.4l0.3,2.2l-1.9,0.3
	V4.7c0-0.4-0.1-0.5-0.3-0.7c-0.1-0.1-0.4-0.3-0.7-0.1c-0.3,0-0.5,0.1-0.6,0.3c-0.1,0.3-0.1,0.5-0.1,0.9l0.3,2.6
	c0,0.4,0.1,0.7,0.3,0.8c0.1,0.1,0.4,0.3,0.7,0.1c0.5,0,0.8-0.3,0.9-0.4l-0.1-1l-1,0.1L14,5.7l2.9-0.3l0.4,3.8
	C16.9,9.5,16.5,9.7,16,10c-0.4,0.1-0.9,0.4-1.4,0.4c-0.7,0-1.2,0-1.6-0.1c-0.3,0-0.6-0.3-0.9-0.5c-0.1-0.3-0.3-0.4-0.4-0.7
	c-0.1-0.3-0.1-0.6-0.3-1.3l-0.3-2.6C11,4.7,11,4.1,11.2,3.9z M11.2,9.7c0,0.3,0,0.5-0.3,0.8c-0.1,0.3-0.4,0.4-0.6,0.4
	c-0.3,0-0.5,0-0.8-0.3c-0.3-0.1-0.4-0.4-0.4-0.7c0-0.3,0-0.5,0.3-0.8C9.5,9,9.7,8.8,10,8.8c0.3,0,0.5,0,0.8,0.3
	C11,9.2,11.2,9.5,11.2,9.7z M8.6,2.7C8.7,2.5,9,2.3,9.4,2.3c0.4,0,0.7,0,0.9,0.3c0.3,0.1,0.4,0.4,0.4,0.8v0.1c0,0.1,0,0.1,0,0.3
	l-0.1,4.4L9.4,8.3V8.2l-1-4.3c0-0.1,0-0.1,0-0.3V3.5C8.3,3.1,8.3,2.9,8.6,2.7z M2.6,10.1C2.7,10,2.9,10,2.9,9.9c0-0.1,0-0.3,0-0.5
	L2.5,5.6c0-0.3-0.1-0.5-0.1-0.5c0-0.1-0.1-0.3-0.3-0.3H1.9L1.8,3.4L4.9,3c1-0.1,1.8,0,2.2,0.4c0.5,0.4,0.8,0.8,0.9,1.6
	c0,0.5,0,0.8-0.3,1.2c0,0.4-0.1,0.7-0.4,0.8C7.7,7,8.1,7.1,8.2,7.4c0.3,0.4,0.5,0.8,0.5,1.3c0,0.3,0,0.3,0,0.6
	c0,0.3-0.1,0.5-0.3,0.6c-0.3,0.4-0.7,0.6-1,0.8c-0.3,0.1-0.8,0.4-1.4,0.5l-3.2,0.3C2.7,11.6,2.6,10.1,2.6,10.1z M7.7,17.3
	c-0.3,0.4-0.8,0.5-1.6,0.6l-2.6,0.3L3.4,17h0.1v-0.1c0-0.1,0-0.3,0-0.4l-0.3-2.9c0-0.3,0-0.4-0.1-0.4c0,0-0.1-0.1-0.3-0.1H2.7v-1
	l2.6-0.3c0.8-0.1,1.3,0,1.7,0.3c0.4,0.1,0.6,0.5,0.6,1.2c0,0.4,0,0.7-0.1,0.9c-0.1,0.3-0.3,0.4-0.4,0.5c0.3,0.1,0.5,0.3,0.7,0.4
	c0.3,0.3,0.3,0.5,0.4,0.9C8.2,16.6,8.1,16.9,7.7,17.3z M12.6,12.6l0.3,2.5c0.1,0.8,0,1.3-0.4,1.7c-0.3,0.4-0.8,0.6-1.6,0.8
	c-0.8,0.1-1.3,0-1.7-0.4c-0.4-0.4-0.7-0.8-0.7-1.6l-0.3-2.5c0-0.1,0-0.3-0.1-0.4c0,0-0.1-0.1-0.3-0.1l-0.1-1l2.2-0.3l0.1,0.9
	c-0.1,0.1-0.3,0.3-0.3,0.4c0,0.1,0,0.3,0,0.5l0.3,2.3c0,0.3,0.1,0.5,0.3,0.7c0.1,0.1,0.3,0.1,0.4,0.1c0.3,0,0.3-0.1,0.4-0.3
	c0.1-0.3,0.1-0.4,0.1-0.7L11,13c0-0.3,0-0.4-0.1-0.5c0-0.1-0.1-0.1-0.3-0.1l-0.1-1l2.3-0.4l0.1,1c-0.1,0-0.1,0.1-0.3,0.1
	C12.6,12.3,12.6,12.5,12.6,12.6z M17.5,11.6c-0.1,0.1-0.3,0.3-0.3,0.4l-0.9,2.5l0.1,0.8c0,0.3,0,0.4,0.1,0.4c0,0,0.1,0.1,0.3,0.1H17
	l0.1,1.2l-2.1,0.3L14.9,16h0.1c0.1,0,0.1,0,0.1-0.1c0-0.1,0-0.3,0-0.4l-0.1-0.8l-1.4-2.2c0-0.1-0.1-0.1-0.1-0.3l-0.1-0.1l-0.1-1
	l1.8-0.1l0.1,0.8c0,0.1,0,0.3,0.1,0.4c0,0.1,0.1,0.1,0.1,0.3l0.4,0.5l0.3-0.7c0-0.1,0-0.1,0-0.3c0-0.1,0-0.3,0-0.4L16,10.8l1.8-0.1
	C17.8,10.6,17.5,11.6,17.5,11.6z"/>
</svg>');
        $position = 40;

        add_menu_page(
            $page_title,
            $menu_title,
            $capability,
            $menu_slug,
            $function,
            $icon_url,
            $position
        );
    }

    /**
     * @return array
     */
    public function defineCronTasks(): array
    {
        $cron = [];

        $systemService = new SystemService();

        if ($systemService->checkFLockExists()){
            $cron['GsCron'] = self::CRON_EVERY_DAY.' '.self::FLOCK_CRON.' '.self::GOOGLE_SHOPPING_CRON.' '.self::CURL_CRON;
            $cron['WcCron'] = self::CRON_EVERY_MINUTE.' '.self::FLOCK_CRON.' '.self::WOOCOMMERCE_CRON.' '.self::CURL_CRON;

            return $cron;
        }

        $cron['GsCron'] = self::CRON_EVERY_DAY.' '.self::CURL_CRON;
        $cron['WcCron'] = self::CRON_EVERY_MINUTE.' '.self::CURL_CRON;

        return $cron;
    }

    /**
     * @throws WooCommerceApiConnectionException
     * @throws Exception
     */
    public function loadAccessAndSecretFormView(): void
    {
        $memoryInfo = [];
        $accountInfoReportService = new AccountInfoReportService();
        $systemService = new SystemService();
        $taxesService = new TaxesService();
        try {
            $accountInfoReport = $accountInfoReportService->getWoocommerceReport();
            $memoryInfo = $systemService->getMemoryInfo();
        } catch (\Exception $exception) {
            $accountInfoReport = [];
        }
    ?>
        <link rel="stylesheet" type="text/css" href="<?php echo plugin_dir_url(__FILE__) . '../assets/css/viewManage.css' ?>" media="screen" />
        <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css" type="text/css" />
    <?php
        if ($_GET['page'] === MipWcConnector::MODULE_NAME && (get_option('woocommerce_version') < MipWcConnector::WC_VERSION)){
            ?>
            <div class="notice notice-error is-dismissible">
                <p>
                    <b><?php echo esc_html_e('BigBuy Dropshipping Connector for WooCommerce', 'WC-Mipconnector'); ?></b>
                    <?php echo esc_html_e(' is not compatible with your version of Woocommerce. Please ', 'WC-Mipconnector'); ?>

                    <b><a href="plugins.php"><?php echo esc_html_e('update the plugin.', 'WC-Mipconnector'); ?></a></b>
                </p>
            </div>
            <?php
        }
        $siteUrl = $this->apiConnection->getOptionBySiteUrl();
        if (!$accountInfoReport){
            ?>
            <h1 class="title-mip-woocommerce"><?php esc_html_e('BigBuy Dropshipping Connector for WooCommerce', 'WC-Mipconnector');?></h1>
            <div class="info-mip-woocommerce">
                <h2><?php esc_html_e('Synchronise your ecommerce with the BigBuy product catalogue.', 'WC-Mipconnector');?></h2>
                <div>
                    <div class="cheklist">
                        <span><img src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>" class="done-icon"></span>
                        <p><strong><?php esc_html_e('+70,000 items of stock', 'WC-Mipconnector');?></strong></p>
                    </div>
                    <div class="cheklist">
                        <span><img src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>" class="done-icon"></span>
                        <p><strong><?php esc_html_e('Categories: ', 'WC-Mipconnector');?></strong><em><?php esc_html_e('Kitchen, Sports, Perfumery, Fashion, Sex Shop, Electronics, IT, Home, Toys...', 'WC-Mipconnector');?></em></p>
                    </div>
                    <div class="cheklist">
                        <span><img src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>" class="done-icon"></span>
                        <p><strong><?php esc_html_e('+2,500 original brands', 'WC-Mipconnector');?></strong></p>
                    </div>
                    <div class="cheklist">
                        <span><img src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>" class="done-icon"></span>
                        <p><strong><?php esc_html_e('Deliveries from 24', 'WC-Mipconnector');?></strong></p>
                    </div>
                    <div class="cheklist">
                        <span><img src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>" class="done-icon"></span>
                        <p><strong><?php esc_html_e( 'Catalogue available in 24 languages', 'WC-Mipconnector');?></strong></p>
                    </div>
                    <div class="cheklist">
                        <span><img src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>" class="done-icon"></span>
                        <p><strong><?php esc_html_e('European stock', 'WC-Mipconnector');?></strong></p>
                    </div>
                    <div class="cheklist">
                        <span><img src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>" class="done-icon"></span>
                        <p><strong><?php esc_html_e('New items daily', 'WC-Mipconnector');?></strong></p>
                    </div>
                    <div class="cheklist">
                        <span><img src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>" class="done-icon"></span>
                        <p><strong><?php esc_html_e('Automatic synchronisation:', 'WC-Mipconnector');?></strong> <em><?php esc_html_e( 'products, categories, orders, carriers, tracking...', 'WC-Mipconnector');?></em></p>
                    </div>
                </div>
                <p><?php esc_html_e('To start the synchronisation process, Log into the ', 'WC-Mipconnector');?><strong class="strong-mip-woocommerce">Multi-Channel Integration Platform</strong><?php esc_html_e(' and follow the steps', 'WC-Mipconnector');?>.</p>
            </div>
            <div class="account-mip-woocommerce">
                <div>
                    <h2><strong><?php esc_html_e( 'Log in ', 'WC-Mipconnector');?>Multi-Channel Integration Platform</strong></h2>
                    <a class="button-mip-woocommerce" href="https://platform.bigbuy.eu" target="_blank"><?php esc_html_e( 'Login', 'WC-Mipconnector');?></a>
                </div>
                <div>
                    <h2><strong><?php esc_html_e( 'Still don’t have a BigBuy account?', 'WC-Mipconnector');?></strong></h2>
                    <a class="button-mip-woocommerce" href="https://www.bigbuy.eu/es/account/create" target="_blank"><?php esc_html_e( 'Register now', 'WC-Mipconnector');?></a>
                </div>
            </div>
            <?php
            return;
        }
        $languageManager = new LanguageReportManager();
        $language = explode('_', $languageManager->getDefaultLanguageIsoCode());
        $this->language = $language[0];
        $dateNow = new \DateTime('now', new \DateTimeZone('UTC'));

        if ($accountInfoReport['LastCronExecutionDate'] === null) {
            $accountInfoReport['LastCronExecutionDate'] = '1000-01-01';
        }

        $cronTasks = $this->defineCronTasks();

        $dateCron = new \DateTime($accountInfoReport['LastCronExecutionDate'], new \DateTimeZone('UTC'));
        $intervalDates = $dateNow->diff($dateCron);
        ?>
        <div class="u-pdr">
            <h1 class="title-mip-woocommerce"><?php esc_html_e('BigBuy Dropshipping Connector for WooCommerce', 'WC-Mipconnector');?></h1>
            <section class="content-section-mip">
                <h3><?php esc_html_e('Step 1: Minimum requirements', 'WC-Mipconnector');?></h3>
                <div id="modal-1" class="modal-cron-ssh" style="display: none">
                    <div class="box-content">
                        <div class="box-title">
                            <p>CRON SSH</p>
                            <input id="cron-text-1" type="text" value="<?php echo $cronTasks['WcCron'] . ' ' . $siteUrl.'/wcmipconnector/readfiles >> '.esc_html(MipWcConnector::LOG_DIR).'/process_import_cron.log'?>">
                        </div>
                        <div class="u-flex-end box-input">
                            <button id="btn-close-modal1" onclick="hideModal1()" class="modal-button cancel u-mr">Cancelar</button>
                            <button id="btn-copy-modal1" onclick="copyModal1()" class="modal-button copy">Copiar</button>
                        </div>
                    </div>
                </div>
                <div id="modal-2" class="modal-cron-ssh" style="display: none">
                    <div class="box-content">
                        <div class="box-title">
                            <p>CRON SSH</p>
                            <input id="cron-text-2" type="text" value="<?php echo $cronTasks['GsCron'] . ' ' . $siteUrl.'/wcmipconnector/updateurls' ?>">
                        </div>
                        <div class="u-flex-end box-input">
                            <button id="btn-close-modal2" onclick="hideModal2()" class="modal-button cancel u-mr">Cancelar</button>
                            <button id="btn-copy-modal2" onclick="copyModal2()" class="modal-button copy">Copiar</button>
                        </div>
                    </div>
                </div>
                <section>
                    <div class="step">
                        <header>
                            <h4 id="RequirementsTitle">
                                <img class="okey-status u-pdt0" id="check-symbol-icon" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg'; ?>" alt="">
                                <b><?php esc_html_e('Minimum requirements', 'WC-Mipconnector');?></b>
                            </h4>
                            <div class="flex-row al-center">
                                <div class="hide">
                                    <span id="constant-recommend-memory"><?= self::RECOMMENDED_MEMORY_LIMIT?></span>
                                    <span id="constant-max-execution"><?= self::RECOMMENDED_MAX_EXECUTION_TIME ?></span>
                                    <span id="constant-currency"><?= self::DEFAULT_CURRENCY ?></span>
                                    <span id="MemoryLimit"><?php echo esc_html($accountInfoReport['MemoryLimit'] / self::BYTES_TO_MB) ?> </span>
                                    <span id="MaxExecutionTime"> <?php echo esc_html($accountInfoReport['MaxExecutionTime']) ?> </span>
                                    <span id="Currency"><?php echo esc_html($accountInfoReport['DefaultCurrency'])?></span>
                                    <span id="Cron"><?php echo esc_html($intervalDates->days < 1 ? 'True' : 'False') ?></span>
                                </div>
                                <div>
                                    <svg class="icon-status" viewBox="0 0 24 24" id="icon-status">
                                        <g>
                                            <path d="M12 2C6.477 2 2 6.477 2 12s4.477 10 10 10 10-4.477 10-10S17.523 2 12 2zm1 15h-2v-6h2v6zm0-8h-2V7h2v2z"></path>
                                        </g>
                                    </svg>
                                    <a id="btn-hide" onclick="hide()" href="#">
                                        <img class="btn-icon"
                                            src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/flecha-arriba.svg'; ?>"
                                            alt="">
                                    </a>
                                    <a id="btn-show" onclick="show()" href="#">
                                        <img class="btn-icon"
                                            src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/flecha-abajo.svg'; ?>"
                                            alt="">
                                    </a>
                                </div>
                            </div>

                        </header>
                        <div id="data-requirements" class="step-content">
                            <div class="step-requisite">
                                <a class="txt-decoration-none" href="<?php echo esc_attr('https://www.bigbuy.eu/academy/'.$this->language.'/');?>" target="_blank">
                                    <div class="academy-button">
                                        <img class="" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/academy.svg' ?>">
                                        <span>
                                    <strong> Academy</strong> - <?php esc_html_e('How to synchronise WooCommerce via the ', 'WC-Mipconnector');?>Multi-Channel Integration Platform
                                </span>
                                    </div>
                                </a>
                            </div>
                            <div class="flex-row step-requisite">
                                <div class="check-status">
                                    <?php
                                    $memoryRamLimitValue = esc_html($memoryInfo['MemTotal']);
                                    if ($memoryRamLimitValue < self::RECOMMENDED_MEMORY_LIMIT) { ?>
                                        <img class="error-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/error.svg' ?>"
                                             alt="">
                                    <?php }
                                    if ($memoryRamLimitValue >= self::RECOMMENDED_MEMORY_LIMIT) { ?>
                                        <img class="okey-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>"
                                             alt="">
                                    <?php }
                                    ?>
                                </div>
                                <div class="step-requisite-info-box">
                                    <h4 class="mg0 strongBB">RAM:</h4>
                                    <div class="step-requisite-info">
                                        <p id="elementMemoryLimit" class="mg0  step-requisite-info-width">
                                            <strong class="strongBB"><?php esc_html_e('Total', 'WC-Mipconnector');?>:</strong> <?php echo esc_html($memoryInfo['MemTotal']) ?>MB
                                        </p>
                                        <p class="mg0">
                                            <b class="strongBB"><?php esc_html_e('Available', 'WC-Mipconnector');?>:</b> <?= $memoryInfo['MemFree']?>MB
                                        </p>
                                    </div>
                                </div>
                            </div>
                            <div class="flex-row step-requisite">
                                <div class="check-status">
                                    <?php

                                    if (!$taxesService->getTaxes()) {
                                        $status = self::TAXES_NOT_CONFIGURED?>
                                        <img class="error-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/error.svg' ?>"
                                             alt="">
                                    <?php }
                                    if ($taxesService->getTaxes()) {
                                        $status = self::STATUS_OK?>
                                        <img class="okey-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>"
                                             alt="">
                                    <?php }
                                    ?>
                                </div>
                                <div class="step-requisite-info-box">
                                    <h4 class="mg0 strongBB">Taxes Created:</h4>
                                    <div class="step-requisite-info">
                                        <p id="elementMemoryLimit" class="mg0  step-requisite-info-width">
                                            <strong class="strongBB"><?php esc_html_e('Status', 'WC-Mipconnector');?>:</strong> <?php echo $status ?>
                                        </p>
                                    </div>
                                </div>
                            </div>
                            <div class="flex-row step-requisite">
                                <div class="check-status">
                                    <?php
                                    $memoryLimitValue = esc_html($accountInfoReport['MemoryLimit'] / self::BYTES_TO_MB);
                                    if ($memoryLimitValue < self::RECOMMENDED_MEMORY_LIMIT) { ?>
                                        <img class="error-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/error.svg' ?>"
                                            alt="">
                                    <?php }
                                    if ($memoryLimitValue >= self::RECOMMENDED_MEMORY_LIMIT) { ?>
                                        <img class="okey-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>"
                                            alt="">
                                    <?php }
                                    ?>
                                </div>
                                <div class="step-requisite-info-box">
                                    <h4 class="mg0 strongBB">Memory Limit:</h4>
                                    <div class="step-requisite-info">
                                            <p id="elementMemoryLimit" class="mg0  step-requisite-info-width">
                                                <strong class="strongBB"><?php esc_html_e('Detected', 'WC-Mipconnector');?>:</strong> <?php echo esc_html($accountInfoReport['MemoryLimit'] / self::BYTES_TO_MB) ?>MB
                                            </p>
                                            <p class="mg0">
                                                <b class="strongBB"><?php esc_html_e('Recommended', 'WC-Mipconnector');?>:</b> <?= self::RECOMMENDED_MEMORY_LIMIT?>MB
                                            </p>
                                    </div>
                                </div>
                            </div>
                            <div class="flex-row step-requisite">
                                <div class="check-status">
                                    <?php
                                        $maxExecutionTime = (int)$accountInfoReport['MaxExecutionTime'];
                                        if ($maxExecutionTime < self::RECOMMENDED_MAX_EXECUTION_TIME && $maxExecutionTime !== 0) { ?>
                                            <img class="error-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/error.svg' ?>"
                                                alt="">
                                        <?php }
                                        if ($maxExecutionTime >= self::RECOMMENDED_MAX_EXECUTION_TIME || $maxExecutionTime === 0) { ?>
                                            <img class="okey-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>"
                                                alt="">
                                        <?php }
                                    ?>
                                </div>
                                <div class="step-requisite-info-box">
                                    <h4 class="mg0 strongBB">Max Execution Time:</h4>
                                    <div class="step-requisite-info">
                                            <p id="elementExecutionTime" class="mg0 step-requisite-info-width">
                                                <strong class="strongBB"><?php esc_html_e('Detected', 'WC-Mipconnector');?>:</strong> <?php echo $maxExecutionTime === 0 ?  esc_html_e('Unlimited', 'WC-Mipconnector'): esc_html($accountInfoReport['MaxExecutionTime'])?>
                                            </p>
                                            <p class="mg0">
                                                <b class="strongBB"><?php esc_html_e('Recommended', 'WC-Mipconnector');?>:</b> <?= self::RECOMMENDED_MAX_EXECUTION_TIME ?>
                                            </p>
                                    </div>
                                </div>
                            </div>
                            <div class="flex-row step-requisite">
                                <div class="check-status">
                                    <?php
                                    $defaultCurrency = $accountInfoReport['DefaultCurrency'];
                                    if ($defaultCurrency !== self::DEFAULT_CURRENCY) { ?>
                                        <img class="error-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/error.svg' ?>"
                                            alt="">
                                    <?php }
                                    if ($defaultCurrency === self::DEFAULT_CURRENCY) { ?>
                                        <img class="okey-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>"
                                            alt="">
                                    <?php }
                                    ?>
                                </div>
                                <div class="step-requisite-info-box">
                                    <h4 class="mg0 strongBB"><?php esc_html_e('Default currency', 'WC-Mipconnector');?>:</h4>
                                    <div class="step-requisite-info">
                                            <p id="elementExecutionTime" class="mg0 step-requisite-info-width">
                                                <strong class="strongBB"><?php esc_html_e('Detected', 'WC-Mipconnector');?>:</strong> <?php echo $defaultCurrency.' '.get_woocommerce_currency_symbol() ?>
                                            </p>
                                            <p class="mg0">
                                                <b class="strongBB"><?php esc_html_e('Required', 'WC-Mipconnector');?>:</b> EUR €
                                            </p>
                                    </div>
                                </div>
                            </div>
                            <div class="flex-row step-requisite no-border">
                                <div class="check-status">
                                    <?php
                                    $cronStatus = esc_html($intervalDates->days < 1 ? 'True' : 'False');
                                    if ($cronStatus === 'False') { ?>
                                        <img class="error-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/error.svg' ?>"
                                            alt="">
                                    <?php }
                                    if ($cronStatus === 'True') { ?>
                                        <img class="okey-status" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/done_alt.svg' ?>"
                                            alt="">
                                    <?php }
                                    ?>
                                </div>
                                <div class="step-requisite-info-box">
                                    <h4 class="mg0 strongBB"><?php esc_html_e('Activate the following programmed tasks (CRON)', 'WC-Mipconnector');?>:</h4>
                                    <div class="u-pdt">
                                        <p class="mg0"><strong class="strongBB"><?php esc_html_e('Frequency', 'WC-Mipconnector');?>:</strong></p>
                                        <p class="mg0"><?php esc_html_e('Every minute', 'WC-Mipconnector');?></p>
                                        <h4 class="mg0"><b class="strongBB">URL:</b></h4>
                                        <p id="data-cron-1" class="mg0 text-responsive linkBB"><?php echo $siteUrl.'/wcmipconnector/readfiles >> '.esc_html(MipWcConnector::MODULE_DIR
                                                ).'/var/logs/process_import_cron.log'?></p>

                                        <p class="text-responsive nomarginBB u-pdt">*<?php esc_html_e('If your server does not accept commands to create CRON, use this url', 'WC-Mipconnector');?>:</p>
                                        <p class="mg0 text-responsive linkBB"><?php echo $siteUrl.'/wcmipconnector/readfiles' ?></p>
                                        <button onclick="showModal1()" class="cron-button mgb-1">
                                            <?php esc_html_e('See CRON command for SSH', 'WC-Mipconnector');?></button>
                                    </div>
                                    <div class="u-pdt2">
                                        <em>*<?php esc_html_e('Only for Google Shopping', 'WC-Mipconnector');?></em>
                                        <h4 class="mg0"><b class="strongBB"><?php esc_html_e('Frequency', 'WC-Mipconnector');?>:</b></h4>
                                        <p class="mg0"><?php esc_html_e('At 00.15 every day', 'WC-Mipconnector');?></p>
                                        <h4 class="mg0"><b class="strongBB">URL:</b></h4>
                                        <p  id="data-cron-2" class="mg0 text-responsive linkBB"><?php echo $siteUrl.'/wcmipconnector/updateurls' ?></p>
                                        <button onclick="showModal2()"  class="cron-button mgb-1">
                                            <?php esc_html_e('See CRON command for SSH', 'WC-Mipconnector');?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>
                <h3 class="u-pdt"><?php esc_html_e('Step 2: Publication from the ', 'WC-Mipconnector');?>Multi-Channel Integration Platform</h3>
                <section class="flex-col content-step2-section-mip">
                    <aside class="step-container" data-steps="1">
                        <figure class="step-item step-current">
                            <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 16 16">
                                <path d="M47.029 141.952L5 183.98V205h21.019l42.029-42.029v-1.914l-19.105-19.104h-1.914zm-22.925 55.405h-5.727v-5.734h-5.736v-5.729l5.736-5.734 11.462 11.463-5.735 5.734zm0-19.103l-3.821-3.82 26.746-26.746 3.821 3.821-26.746 26.745zm59.373-38.088l-13.643-13.643c-2.031-2.031-5.354-2.031-7.385 0l-2.946 2.945c-.021.021-.032.043-.052.063l-6.688 6.692 21.01 21.012 6.695-6.69c.02-.019.043-.03.061-.049l2.947-2.946c2.032-2.03 2.032-5.355.001-7.384zM2 11.501V14h2.5l7.373-7.373-2.499-2.499L2 11.501zm11.805-6.807c.26-.26.26-.68 0-.94l-1.56-1.559a.662.662 0 0 0-.94 0l-1.22 1.219 2.5 2.5 1.22-1.22z"/>
                            </svg>
                            <figcaption class="step-caption"><?php esc_html_e('Configuration', 'WC-Mipconnector');?></figcaption>
                        </figure>
                        <figure class="step-line"></figure>
                        <figure class="step-item">
                            <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 24 24">
                                <path d="M19.4 13c0-.3.1-.6.1-1s0-.7-.1-1l2.1-1.6c.2-.1.2-.4.1-.6l-2-3.5c-.1-.2-.4-.3-.6-.2l-2.5 1c-.5-.4-1.1-.7-1.7-1l-.4-2.7c.1-.2-.1-.4-.4-.4h-4c-.2 0-.5.2-.5.4l-.4 2.7c-.6.2-1.1.6-1.7 1l-2.4-1c-.3-.1-.5 0-.7.2l-2 3.5c-.1.2 0 .4.2.6l2.1 1.6c0 .3-.1.6-.1 1s0 .7.1 1l-2.1 1.6c-.2.1-.2.4-.1.6l2 3.5c.1.3.3.3.6.3l2.5-1c.5.4 1.1.7 1.7 1l.4 2.6c0 .2.2.4.5.4h4c.3 0 .5-.2.5-.4l.4-2.6c.6-.3 1.2-.6 1.7-1l2.5 1c.2.1.5 0 .6-.2l2-3.5c.1-.2.1-.5-.1-.6l-2.3-1.7zm-7.4 2.5c-1.9 0-3.5-1.6-3.5-3.5s1.6-3.5 3.5-3.5 3.5 1.6 3.5 3.5-1.6 3.5-3.5 3.5z"/>
                            </svg>
                            <figcaption class="step-caption"><?php esc_html_e('Languages and taxes', 'WC-Mipconnector');?></figcaption>
                        </figure>
                        <figure class="step-line"></figure>
                        <figure class="step-item">
                            <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 50 50">
                                <path d="M25 16.8l-1.4.2c-.1 0-.3.2-.3.3v2.3c0 .2.1.3.3.3l1.6.2c.2.4.4.7.6 1l-.6 1.4c-.1.1 0 .3.1.4l2.1 1.1c.1.1.3 0 .4-.1l.9-1.2c.4.1.7 0 1.1 0l.9 1.2c0 .2.2.2.3.1l2.1-1.1c.1-.1.2-.2.1-.4l-.6-1.4c.1-.2.2-.3.3-.5.1-.2.2-.4.3-.5l1.5-.2c.1 0 .3-.2.3-.3v-2.3c0-.2-.1-.3-.3-.3l-1.7-.1c-.2-.4-.4-.7-.6-1l.6-1.4c.1-.1 0-.3-.1-.4L30.8 13c-.1-.1-.3 0-.4.1l-.9 1.2c-.4-.1-.7 0-1.1 0l-.9-1.3c-.1-.1-.3-.2-.4-.1l-2 1c-.1.2-.1.2-.1.4l.6 1.4c-.1.2-.2.3-.3.5-.1.2-.2.4-.3.6zm2.7.8c.5-.7 1.4-1 2.2-.6.7.5 1 1.4.6 2.2-.5.7-1.4 1-2.2.6-.8-.4-1.1-1.4-.6-2.2zm-7 5.4l-.3 2c-.5.2-.8.5-1.2.7l-1.8-.7c-.2-.1-.4 0-.5.2l-1.5 2.5c-.1.2-.1.4.1.5l1.5 1.2c0 .2-.1.5-.1.7s0 .5.1.7L15.5 32c-.1.1-.2.3-.1.5l1.5 2.5c.1.2.3.2.5.2l1.8-.7c.4.3.7.6 1.2.7l.3 2c0 .2.2.3.4.3H24c.2 0 .4-.1.4-.3l.3-2c.5-.2.8-.5 1.2-.7l1.8.7c.2.1.4 0 .5-.2l1.5-2.5c.1-.2.1-.4-.1-.5l-1.5-1.2c0-.2.1-.5.1-.7s0-.5-.1-.7l1.5-1.2c.1-.1.2-.3.1-.5L28 25.2c-.1-.2-.2-.2-.4-.2l-1.8.7c-.4-.3-.7-.6-1.2-.7l-.3-2c0-.2-.2-.3-.4-.3H21c-.2.1-.3.1-.3.3zm1.7 5c1.1 0 2.1.9 2.1 2.1 0 1.1-.9 2.1-2.1 2.1-1.1 0-2.1-.9-2.1-2.1.2-1.3 1-2.1 2.1-2.1zM43 14.9C39.5 8.6 32.8 4.4 25.1 4.4 15 4.4 6.7 11.7 4.9 21.3h4.8c1.7-7 8-12.2 15.4-12.2 6.4 0 11.9 3.8 14.4 9.3l-2.9 2.9H46v-9.4s-3 3-3 3zm-17.9 26c-6.3 0-11.6-3.6-14.2-8.8l3.4-3.4H4V39l3.5-3.5c3.6 6 10.2 10 17.7 10 10.1 0 18.4-7.3 20.2-16.8h-4.8c-1.7 7.1-8 12.2-15.5 12.2z"/>
                            </svg>
                            <figcaption class="step-caption"><?php esc_html_e('Synchronisation', 'WC-Mipconnector');?></figcaption>
                        </figure>
                        <figure class="step-line"></figure>
                        <figure class="step-item">
                            <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 14 14">
                                <path d="M9.3 5.1h-.3v-1.2c-.1-1.6-1.9-2.8-4-2.8s-3.9 1.2-4 2.8v6.2c.1 1.6 1.8 2.9 4 2.9.9 0 1.6-.2 2.3-.5.6.3 1.3.5 2 .5 2.2 0 4-1.8 4-4s-1.8-3.9-4-3.9zm-3.9 5h-.4c-1.6 0-3-.9-3-2 .7.6 1.8 1 3 1h.3c0 .3 0 .6.1 1zm0-2h-.4c-1.6 0-3-.9-3-2 .7.6 1.8 1 3 1 .3 0 .6 0 .9-.1-.2.3-.4.7-.5 1.1zm-.4-6c1.6 0 3 .9 3 2s-1.4 2-3 2-3-.9-3-2 1.4-2 3-2zm-3 8c.7.6 1.8 1 3 1 .3 0 .5 0 .8-.1.2.3.4.6.6.8-.4.2-.9.3-1.4.3-1.6 0-3-.9-3-2zm7.3 2c-1.7 0-3-1.3-3-3s1.3-3 3-3 3 1.3 3 3-1.4 3-3 3z"/>
                            </svg>
                            <figcaption class="step-caption"><?php esc_html_e('Price strategy', 'WC-Mipconnector');?></figcaption>
                        </figure>
                    </aside>
                    <div class="step2-container">
                        <p class="strongBB"><?php esc_html_e('Once the minimum requirements are met, you can now carry out the synchronisation of your store from the ', 'WC-Mipconnector');?> Multi-Channel
                            Integration Platform.</p>
                        <p><strong><?php esc_html_e('What can be done with the BigBuy Dropshipping Connector plugin for WooCommerce?', 'WC-Mipconnector');?></strong></p>
                        <ul class="nomarginBB">
                            <li>-<?php esc_html_e('Catalogue synchronisation: images, texts, videos, categories, brands, tags, etc.', 'WC-Mipconnector');?></li>
                            <li>-<?php esc_html_e('Synchronisation of stock and prices in real time.', 'WC-Mipconnector');?></li>
                            <li>-<?php esc_html_e('Automated pricing rules by price ranges, categories and products.', 'WC-Mipconnector');?></li>
                            <li>-<?php esc_html_e('Synchronisation of orders: shipping prices, carriers and tracking.', 'WC-Mipconnector');?></li>
                        </ul>
                        <a class="u-pdt" href="<?php echo esc_attr('http://platform.bigbuy.eu/'.$this->language.'/controlpanel/configuration/2');?>" target="_blank">
                            <button class="u-mgh button button-primary"><?php esc_html_e('Go to the', 'WC-Mipconnector');?> Multi-Channel Integration Platform</button>
                        </a>
                        <a class="txt-decoration-none" href="<?php echo esc_attr('https://www.bigbuy.eu/academy/'.$this->language.'/');?>" target="_blank">
                            <div class="academy-button">
                                <img class="" src="<?php echo plugin_dir_url(__FILE__) . '../assets/image/academy.svg' ?>">
                                <span>
                                    <strong> Academy</strong> - <?php esc_html_e('How to synchronise WooCommerce via the ', 'WC-Mipconnector');?>Multi-Channel Integration Platform
                                </span>
                            </div>
                        </a>
                    </div>
                </section>
                <h3 class="u-pdt"><?php esc_html_e('Step 3: Additional settings', 'WC-Mipconnector');?></h3>
                <?php
                if (isset($_POST['save'])) {
                    $this->apiConnection->saveBlackFridayOption($_POST['tagOption']);

                    if (!$_POST['tagOption']) {
                        $blackFridayName = MipWcConnector::WC_MIPCONNECTOR_TAG_NAME;
                        $this->tagManager->deleteByName($blackFridayName);
                    }

                    if (isset($_POST['sendEmail'])) {
                        $sendEmailStatus = (int)$_POST['sendEmail'];
                        $this->apiConnection->saveSendEmailConfiguration($sendEmailStatus);
                    }
                    if (isset($_POST['bigbuyCarrierOption'])) {
                        $bigbuyCarrierOption = (int)$_POST['bigbuyCarrierOption'];
                        $this->apiConnection->saveBigBuyCarrierOption($bigbuyCarrierOption);

                        if (!$bigbuyCarrierOption) {
                            $zoneService = new ZoneService();
                            $zoneService->createAllWorldZoneIfNotExists();
                        }
                    }
                }

                $tagOption = $this->apiConnection->getTagOption();
                $sendEmail = $this->apiConnection->getSendEmailConfiguration();
                $bigbuyCarrierOption = $this->apiConnection->getBigBuyCarrierOption();
                ?>

            </section>
            <form id="saveConfiguration" method="post">
                   
                    <section class="flex-col content-step2-section2-mip tag-content">
                        <div class="flex-row tag-item-content">
                            <div class="tag-item-info flex-between">
                                <p><b><?php esc_html_e('Tag ´Black Friday/Cyber Monday´', 'WC-Mipconnector');?></b></p>
                                <i class="fa fa-question-circle grey tooltip-position">
                                    <span class="tooltip-text"><?php esc_html_e('This option enables you to synchronise special offers labels in your store. Example: Black Friday.', 'WC-Mipconnector');?></span>
                                </i>
                            </div>
                            
                            <div id="formData" class="tag-item-options" 
                                data-FormTagBlackFriday="<?php echo esc_attr($tagOption ? 1 : 0); ?>"
                                data-formEmail="<?php echo esc_attr($sendEmail ? 1 : 0); ?>"
                                data-formCarriers="<?php echo esc_attr($bigbuyCarrierOption?1:0); ?>">
                                <p>
                                    <input datajs-form-el="Option" type="radio" name="tagOption"
                                        value="1" <?php echo esc_attr($tagOption ? 'checked' : ''); ?>><?php esc_html_e('Yes', 'WC-Mipconnector') ?></input>
                                </p>
                                <p>
                                    <input datajs-form-el="Option" type="radio" name="tagOption"
                                        value="0" <?php echo esc_attr(!$tagOption ? 'checked' : ''); ?>><?php esc_html_e('No', 'WC-Mipconnector') ?></input>
                                </p>
                            </div>
                        </div>
                        <div class="flex-row tag-item-content">
                            <div class="tag-item-info flex-between">
                                <p><b><?php esc_html_e('Email order updates', 'WC-Mipconnector');?></b></p>
                                <i class="fa fa-question-circle grey tooltip-position">
                                    <span class="tooltip-text"><?php esc_html_e('This option enables you to choose whether you want to receive emails for each status change update.', 'WC-Mipconnector');?></span>
                                </i>
                            </div>
                            <div class="tag-item-options">
                                <p>
                                    <input datajs-form-el="Option" type="radio" name="sendEmail"
                                        value="1" <?php echo esc_attr($sendEmail ? 'checked' : ''); ?>><?php esc_html_e('Yes', 'WC-Mipconnector') ?></input>
                                </p>
                                <p>
                                    <input datajs-form-el="Option" type="radio" name="sendEmail"
                                        value="0" <?php echo esc_attr(!$sendEmail ? 'checked' : ''); ?>><?php esc_html_e('No', 'WC-Mipconnector') ?></input>
                                </p>
                            </div>
                        </div>
                        <div class="flex-row tag-item-last">
                            <div class="tag-item-content">
                                <div class="tag-item-info flex-between">
                                    <p><b><?php esc_html_e('Manual synchronisation of carriers', 'WC-Mipconnector');?></b></p>
                                    <i class="fa fa-question-circle grey tooltip-position">
                                        <span class="tooltip-text"><?php esc_html_e('If you are going to use multiple suppliers in your store, you should select the option ‘Yes’, and create the carriers manually. If you select ‘No’, we will automatically charge the prices of the BigBuy carriers.', 'WC-Mipconnector');?></span>
                                    </i>
                                </div>
                                <div class="tag-item-options">
                                    <p class="flex">
                                        <input datajs-form-el="Option" type="radio" name="bigbuyCarrierOption"
                                            value="1" <?php echo esc_attr($bigbuyCarrierOption?'checked':''); ?>><?php esc_html_e('Yes', 'WC-Mipconnector') ?></input>
                                    </p>
                                    <p class="flex">
                                        <input datajs-form-el="Option" type="radio" name="bigbuyCarrierOption"
                                            value="0" <?php echo esc_attr(!$bigbuyCarrierOption?'checked':''); ?>><?php esc_html_e('No', 'WC-Mipconnector') ?></input>
                                    </p>
                                </div>
                            </div>

                                    <?php if(!$bigbuyCarrierOption && $this->zoneService->checkIfAllWorldZoneLocalPickupExists()) { ?>
                                    <div class="box-info">
                                        <span class="box-icon box-info-icon">
                                            <svg  viewBox="0 0 24 24" >
                                                <g>
                                                    <path d="M12 2C6.477 2 2 6.477 2 12s4.477 10 10 10 10-4.477 10-10S17.523 2 12 2zm1 15h-2v-6h2v6zm0-8h-2V7h2v2z"></path>
                                                </g>
                                            </svg>
                                        </span>
                                        <span class="box-info-content">
                                            <span class="notice__text"><?php esc_html_e('Do not modify the ‘All world’ delivery area since this is the one used by the plugin to synchronise the carrier costs', 'WC-Mipconnector');?></span>
                                        </span>
                                     </div>
                                    <?php }
                                    if (!$bigbuyCarrierOption && !$this->zoneService->checkIfAllWorldZoneLocalPickupExists()) { ?>
                                    <div id="isErrorMessage" class="box-info">
                                        <span class="box-icon box-error-icon">
                                            <svg viewBox="0 0 24 24" id="gridicons-notice">
                                                <g>
                                                    <path d="M12 2C6.477 2 2 6.477 2 12s4.477 10 10 10 10-4.477 10-10S17.523 2 12 2zm1 15h-2v-2h2v2zm0-4h-2l-.5-6h3l-.5 6z"></path>
                                                </g>
                                            </svg>
                                        </span>
                                        <span class="box-info-content">
                                            <span class="notice__text"><?php esc_html_e('Do not modify the ‘All world’ delivery area since this is the one used by the plugin to synchronise the carrier costs', 'WC-Mipconnector');?></span>
                                        </span>
                                    </div>
                                    <?php } ?>

                        </div>
                    </section>
                    <input class="button button-primary" type="submit" name='save' value='<?php esc_attr_e('Save', 'WC-Mipconnector'); ?>'/>
            </form>

        </div>
       
        <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.4.1/jquery.min.js"></script>
        <script src="<?php echo plugin_dir_url(__FILE__) . '../assets/js/viewManage.js' ?>"></script>
        <?php
    }
}
