<?php

namespace WcMipConnector\Controller;

require_once __DIR__.'/../../vendor/autoload.php';

use WcMipConnector\Enum\MipWcConnector;
use WcMipConnector\Manager\FileLogManager;
use WcMipConnector\Service\FileLogService;
use WcMipConnector\Service\FileService;
use WcMipConnector\Service\LoggerService;
use WcMipConnector\Service\SystemService;
use WcMipConnector\Service\WoocommerceApiConnectionService;

/**
 * Class FileController
 *
 * @package WcMipConnector\Controller
 */
class FileController
{
    private const MINIMUM_STORAGE_VALUE = 0.5;

    public function executeSynchronization(): void
    {
        $logger = new LoggerService;
        $systemService = new SystemService();

        $checkSystemStorage = $systemService->getStorageServerInfo();

        if ($checkSystemStorage['Available'] < self::MINIMUM_STORAGE_VALUE){
            $logger->getInstance()->warning('There is not enough disk space');
            return;
        }

        try {
            $wooConnection = new WoocommerceApiConnectionService;
            $wooConnection->get('system_status');
        }
        catch (\Exception $e){
            $logger->getInstance()->warning('Connection API failed, check API parameters. Message returned: '.$e);
            return;
        }

        $systemService->resetExecutionLimits();

        if (!$systemService->enablePlugin()) {
            $logger->getInstance()->warning('Plugin is not active');
            return;
        }

        $this->controlFileExecutionTime();

        $this->createCronExecutionLogFile();

        $fileLogService = new FileLogService();
        $fileLogService->checkOldFileLog();

        $fileService = new FileService();

        try {
            $fileService->processFile();
        } catch (\Exception $exception) {
            $logger->getInstance()->error('Error in ProcessFile , message: '.$exception);
            return;
        }
    }

    /**
     * @return bool|null
     */
    private function controlFileExecutionTime(): ?bool
    {
        $fileLogManager = new FileLogManager();
        $filesLocked = $fileLogManager->checkForLockedFile();
        if (!$filesLocked) {
            return true;
        }

        foreach ($filesLocked as $fileLocked) {
            $fileLogManager->resetFileState((int)$fileLocked['file_id']);
        }
        return  true;
    }

    public function createCronExecutionLogFile():void
    {
        $timezone = new \DateTimeZone('UTC');
        $currentDate = new \DateTime();
        $currentDate->setTimezone($timezone);
        file_put_contents(MipWcConnector::LOG_DIR.'/'.MipWcConnector::CRON_EXECUTION_LOG_FILENAME, $currentDate->format(DATE_W3C));
    }
}