<?php

namespace WcMipConnector\Controller;

defined('ABSPATH') || exit;

use WcMipConnector\Enum\MipWcConnector;
use WcMipConnector\Exception\WooCommerceApiConnectionException;
use WcMipConnector\Manager\OAuthManager;
use WcMipConnector\Service\ZoneService;

class OAuthController
{
    private const ACCESS_TOKEN = 'access_token';
    private const SECRET_KEY = 'secret_key';
    private const CALLBACK_URL = 'callback-url';
    private const SHOP_URL = 'shop-url';
    private const SHOP_NAME = 'shop-name';

    /**
     * @return bool
     * @throws WooCommerceApiConnectionException
     */
    public function handleAuthRequests(): bool
    {
        global $wp;

        if (empty($_GET) || empty($_GET[self::CALLBACK_URL])) {
            return false;
        }

        if (array_key_exists('mip-route', $wp->query_vars) && ($wp->query_vars['mip-route'] === 'authorize') && !is_user_logged_in()) {
            $this->loadLoginTemplate();
            exit;
        }

        if (array_key_exists('mip-route', $wp->query_vars) && ($wp->query_vars['mip-route'] === 'authorize') && is_user_logged_in()) {
            $this->loadGrantTemplate();
            exit;
        }

        if (array_key_exists('mip-route', $wp->query_vars) && ($wp->query_vars['mip-route'] === 'grant-access') && is_user_logged_in() && current_user_can('manage_woocommerce')) {
            $woocommerceCredentials = $this->createApiCredentials();

            if(!$woocommerceCredentials) {
                wp_redirect($_GET[self::CALLBACK_URL]);
                exit;
            }

            $zoneService = new ZoneService();
            $zoneService->createAllWorldZoneIfNotExists();

            $userSellingChannelUrl = $_GET[self::CALLBACK_URL].'?'.self::SHOP_URL.'='.$_GET[self::SHOP_URL].'&'.self::SHOP_NAME.'='.get_bloginfo('name');
            $callBackUrl = $this->buildCallBackUrl($woocommerceCredentials, $userSellingChannelUrl);

            if ($callBackUrl) {
                wp_redirect($callBackUrl);
                exit;
            }
        }
    }

    public function loadLoginTemplate(): void
    {
        require_once MipWcConnector::VIEWS_DIR.'/auth/LoginForm.php';
    }

    public function loadGrantTemplate(): void
    {
        require_once MipWcConnector::VIEWS_DIR.'/auth/GrantAccess.php';
    }

    /**
     * @return array|null
     */
    public function createApiCredentials(): ?array
    {
        $manager = new OAuthManager();

        if ($manager->checkIfExistsApiAccess())
        {
            return array(
                'consumer_key'    => get_option('WC_MIPCONNECTOR_ACCESS_TOKEN'),
                'consumer_secret' => get_option('WC_MIPCONNECTOR_SECRET_KEY'),
            );
        }

        $consumerKey = 'ck_'.wc_rand_hash();
        $consumerSecret = 'cs_'.wc_rand_hash();

        if($manager->createApiCredentials($consumerKey, $consumerSecret)) {
            return array(
                'consumer_key'    => $consumerKey,
                'consumer_secret' => $consumerSecret,
            );
        }

        return null;
    }

    /**
     * @param array $woocommerceCredentials
     * @param string $userSellingChannelUrl
     * @return string
     */
    public function buildCallBackUrl(array $woocommerceCredentials, string $userSellingChannelUrl): string
    {
        return $userSellingChannelUrl.'&'.self::ACCESS_TOKEN.'='.$woocommerceCredentials['consumer_key'].'&'.self::SECRET_KEY.'='.$woocommerceCredentials['consumer_secret'];
    }
}