<?php

namespace WcMipConnector\Controller;

require __DIR__.'/../../vendor/autoload.php';

use WcMipConnector\Manager\OrderLogManager;
use WcMipConnector\Enum\WooCommerceOrderStatus;
use WcMipConnector\Manager\SystemManager;
use WcMipConnector\Service\LoggerService;

class OrderController
{
    /** @var OrderLogManager  */
    private $orderLogManager;
    /** @var SystemManager  */
    private $systemManager;
    /** @var LoggerService  */
    private $logger;

    public function __construct()
    {
        $this->orderLogManager = new OrderLogManager();
        $this->systemManager = new SystemManager();
        $loggerService = new LoggerService();
        $this->logger = $loggerService->getInstance();
    }

    public function processAction(): void
    {
        $this->systemManager->resetFailureCount();
        $order = json_decode(@file_get_contents('php://input'), true);
        $orderLog = $this->orderLogManager->getByOrderId((int) $order['id']);

        if(!$orderLog && array_key_exists('status', $order) && ($order['status'] === WooCommerceOrderStatus::PROCESSING)) {
            $this->orderLogManager->save($order);
            $this->logger->info('The order '.$order['id'].' has been mapped.');
        }
    }
}