<?php

namespace WcMipConnector\Factory;

defined('ABSPATH') || exit;

use WcMipConnector\Enum\MipWcConnector;
use WcMipConnector\Model\AccountInfoReportModel;
use WcMipConnector\Model\WoocommerceReportModel;

class AccountInfoReportFactory
{
    private const EURO_ISO_CODE = 'EUR';

    /**
     * @param array $accountInfoReport
     * @return AccountInfoReportModel
     */
    public static function create(array $accountInfoReport): AccountInfoReportModel
    {
        $moduleInfo = get_plugin_data(MipWcConnector::MODULE_DIR.'/WcMipconnector.php');

        $accountInfoReportModel = new AccountInfoReportModel();
        $accountInfoReportModel->Version = $moduleInfo['Version'];
        $accountInfoReportModel->Installed = is_plugin_active(MipWcConnector::MODULE_NAME.'/WcMipconnector.php');
        $accountInfoReportModel->MultiShop = $accountInfoReport['environment']['wp_multisite'];
        $accountInfoReportModel->PhpVersion = $accountInfoReport['environment']['php_version'];
        $accountInfoReportModel->MaxExecutionTime = $accountInfoReport['environment']['php_max_execution_time'];
        $accountInfoReportModel->DefaultCurrency = $accountInfoReport['settings']['currency'] === self::EURO_ISO_CODE;
        $accountInfoReportModel->Curl = $accountInfoReport['environment']['fsockopen_or_curl_enabled'];
        $accountInfoReportModel->FileFolderPermissions = (is_writable(MipWcConnector::IMPORTFILES_DIR) && is_readable(MipWcConnector::IMPORTFILES_DIR));
        $accountInfoReportModel->ShopName = get_bloginfo('name');

        $cronExecutionFilename = MipWcConnector::LOG_DIR.'/'.MipWcConnector::CRON_EXECUTION_LOG_FILENAME;
        if (file_exists($cronExecutionFilename)) {
            $timezone = new \DateTimeZone('UTC');
            $lastCronExecutionDate = \DateTime::createFromFormat(
                DATE_W3C,
                file_get_contents($cronExecutionFilename),
                $timezone
            );
            $accountInfoReportModel->LastCronExecutionDate = $lastCronExecutionDate->format(DATE_W3C);
        }

        $accountInfoReportModel->WooCommerceVersion = $accountInfoReport['environment']['version'];
        $accountInfoReportModel->WordPressVersion = $accountInfoReport['environment']['wp_version'];

        return $accountInfoReportModel;
    }

    /**
     * @param array $woocommerceReport
     * @return WoocommerceReportModel
     */
    public static function createWoocommerceReport(array $woocommerceReport): WoocommerceReportModel
    {
        $lastCronExecutionDate = null;
        $cronExecutionFilename = MipWcConnector::LOG_DIR.'/'.MipWcConnector::CRON_EXECUTION_LOG_FILENAME;

        $woocommerceReportModel = new WoocommerceReportModel();
        $woocommerceReportModel->LastCronExecutionDate = null;
        $woocommerceReportModel->MemoryLimit = $woocommerceReport['environment']['wp_memory_limit'];
        $woocommerceReportModel->MaxExecutionTime = $woocommerceReport['environment']['php_max_execution_time'];
        $woocommerceReportModel->DefaultCurrency = $woocommerceReport['settings']['currency'];

        if (file_exists($cronExecutionFilename)) {
            $timezone = new \DateTimeZone('UTC');
            $lastCronExecutionDate = \DateTime::createFromFormat(
                DATE_W3C,
                file_get_contents($cronExecutionFilename),
                $timezone
            );
        }

        if ($lastCronExecutionDate !== null && $lastCronExecutionDate) {
            $woocommerceReportModel->LastCronExecutionDate = $lastCronExecutionDate->format('Y-m-d H:i:s');
        }

        return $woocommerceReportModel;
    }
}