<?php

namespace WcMipConnector\Factory;

defined('ABSPATH') || exit;

use WcMipConnector\Entity\CategoryLang;
use WcMipConnector\Entity\Category;
use WcMipConnector\Manager\CategoryMapManager;

class CategoryFactory
{
    /**
     * @param array $categoryData
     * @param bool $overrideCategoryTree
     * @param int $categoryParentId
     * @param array $languages
     * @return Category
     */
    public function create(array $categoryData, bool $overrideCategoryTree, $categoryParentId = 0, array $languages): Category
    {
        $categoryModel = new Category();
        $categoryLangModel = $this->createLang($categoryData['CategoryLangs'], $languages);
        $categoryModel->name = $categoryLangModel->name;
        $categoryModel->slug = $categoryLangModel->slug;

        if($overrideCategoryTree){
            $categoryModel->image = ['src' => $categoryData['ImageURL']];
            $categoryModel->parent = $categoryParentId;
        }

        return $categoryModel;
    }

    /**
     * @param array $categoryData
     * @param array $languages
     * @return CategoryLang
     */
    private function createLang(array $categoryData, array $languages): CategoryLang
    {
        $categoryLangModel = new CategoryLang();

        foreach ($categoryData as $categoryLang) {
            if (in_array($categoryLang['IsoCode'], $languages, true)) {
                $categoryLangModel->name = $categoryLang['CategoryName'];
                $categoryLangModel->slug = $categoryLang['CategoryURL'];
            }
        }
        return $categoryLangModel;
    }
}