<?php

namespace WcMipConnector\Factory;

defined('ABSPATH') || exit;

use WcMipConnector\Model\Order;

class OrderFactory
{
    /**
     * @param array $order
     * @return Order
     */
    public function create(array $order): Order
    {
        $shippingAddressFactory = new ShippingAddressFactory();
        $orderLineFactory = new OrderLineFactory();
        $orderTotalFactory = new OrderTotalFactory();
        $shippingCostFactory = new ShippingCostFactory();

        $orderModel = new Order();
        $orderModel->OrderID = $order['id'];
        $orderModel->Reference = $order['number'];
        $orderModel->Currency = $order['currency'];
        $orderModel->OrderTotal = $orderTotalFactory->create($order);
        $orderModel->PaymentMethod = $order['payment_method_title'];
        $orderModel->DateCreated = $order['date_created'];
        $orderModel->DateUpdated = $order['date_modified'];
        $orderModel->ShippingAddress = $shippingAddressFactory->create($order);
        $orderModel->ShippingCost = $shippingCostFactory->create($order);
        $orderModel->OrderLines = $orderLineFactory->create($order);
        $orderModel->State = $order['status'];

        return $orderModel;
    }

    /**
     * @param array $order
     * @param string $newStateId
     * @return array
     */
    public function setOrderStatus(array $order, string $newStateId): array
    {
        $order['status'] = $newStateId;
        return $order;
    }

    /**
     * @param array $orderData
     * @return array
     */
    public function setOrderTracking(array $orderData): array
    {
        $orderNote = [
            'note' => $orderData['CarrierProviderName'].' tracking: '.$orderData['TrackingNumber'],
            'customer_note' => true
        ];

        return $orderNote;
    }
}