<?php

namespace WcMipConnector\Factory;

defined('ABSPATH') || exit;

use WcMipConnector\Model\OrderLine;

class OrderLineFactory
{
    /**
     * @param array $order
     * @return OrderLine[]
     */
    public function create(array $order): array
    {
        $orderItems = [];
        $itemPriceFactory = new ItemPriceFactory();
        $itemTaxFactory = new ItemTaxFactory();
        $shippingPriceFactory = new ShippingPriceFactory();
        $shippingPrice = $shippingPriceFactory->create($order);
        $shippingTaxFactory = new ShippingTaxFactory();
        $shippingTax = $shippingTaxFactory->create($order);

        foreach ($order['line_items'] as $line) {
            $orderLine = new OrderLine();
            $itemPrice = $itemPriceFactory->create($line, $order['currency']);
            $itemTax = $itemTaxFactory->create($line, $order['currency']);
            $orderLine->ASIN = $line['sku'];
            $orderLine->Reference = $line['id'];
            $orderLine->ItemPrice = $itemPrice;
            $orderLine->ItemTax = $itemTax;
            $orderLine->OrderItemId = $line['id'];
            $orderLine->QuantityOrdered = $line['quantity'];
            $orderLine->SellerSKU = $line['sku'];
            $orderLine->ShippingPrice = $shippingPrice;
            $orderLine->ShippingTax = $shippingTax;
            $orderLine->ItemTitle = $line['name'];
            $orderItems[] = $orderLine;
        }

        return $orderItems;
    }
}