<?php

namespace WcMipConnector\Factory;

defined('ABSPATH') || exit;

use WcMipConnector\Entity\Dimension;
use WcMipConnector\Entity\ProductApi;
use WcMipConnector\Entity\ProductLang;
use WcMipConnector\Entity\Src;

class ProductFactory
{
    private const PUBLISH_STATUS = 'publish';
    private const VISIBILITY_STATUS = 'visible';
    private const VARIABLE = 'variable';
    private const SIMPLE = 'simple';
    public const MAXIMUM_AVAILABLE_STOCK = 10;

    /**
     * @param array $product
     * @param array $tagIds
     * @param array $categoryIds
     * @param array $brandIds
     * @param array $attributesIds
     * @param array $languages
     * @return ProductApi
     */
    public function create(array $product = null, array $tagIds = null, array $categoryIds = null, array $brandIds = null, array $attributesIds = [], array $languages): ProductApi
    {
        $productModel = new ProductApi();

        $productLangModel = $this->createLang($product['ProductLangs'], $languages);

        $productModel->name = $productLangModel->title;
        $productModel->description = $productLangModel->description;
        $productModel->sku = $product['SKU'];
        $productModel->price = $product['Price'];
        $productModel->regular_price = (string)$product['Price'];
        $productModel->sale_price = (string)$product['Price'];
        $productModel->type = self::SIMPLE;

        if ($product['Variations']) {
            $productModel->type = self::VARIABLE;
        }

        if ($product['Stock'] > 0) {
            $productModel->in_stock = true;
        }

        $productModel->manage_stock = true;
        $productModel->stock_quantity = $this->checkStock($product['Stock']);
        $productModel->weight = (string)$product['Weight'];

        $dimensionModel = new Dimension();
        $dimensionModel->length = (string)$product['Length'];
        $dimensionModel->width = (string)$product['Width'];
        $dimensionModel->height = (string)$product['Height'];

        $productModel->status = self::PUBLISH_STATUS;
        $productModel->catalog_visibility = self::VISIBILITY_STATUS;

        $productModel->dimensions = $dimensionModel;
        $productModel->images = $this->createImage($product['Images']);
        $productModel->tags = $tagIds;
        $productModel->categories = $categoryIds;

        $attributes = array_merge($attributesIds, [$brandIds]);
        $productModel->attributes = $attributes;

        return $productModel;
    }

    /**
     * @param array $productLangs
     * @param array $languages
     * @return ProductLang
     */
    private function createLang(array $productLangs, array $languages): ProductLang
    {
        $productLangModel = new ProductLang();

        foreach ($productLangs as $productLang) {
            if (in_array($productLang['IsoCode'], $languages, true)) {
                $productLangModel->title = $productLang['Title'];
                $productLangModel->description = $productLang['Description'];
            }
        }

        return $productLangModel;
    }

    /**
     * @param array $productImages
     *
     * @return array
     */
    private function createImage(array $productImages): array
    {
        $images = [];

        foreach ($productImages as $productImage) {
            $srcModel = new Src();
            $srcModel->src = $productImage['ImageURL'];

            $images[] = $srcModel;
        }

        return $images;
    }

    /**
     * @param int $productStock
     *
     * @return int
     */
    private function checkStock(int $productStock): int
    {
        if ($productStock > self::MAXIMUM_AVAILABLE_STOCK){
            return self::MAXIMUM_AVAILABLE_STOCK;
        }

        return $productStock;
    }
}