<?php

namespace WcMipConnector\Manager;

defined('ABSPATH') || exit;

use Exception;
use WcMipConnector\Exception\WooCommerceApiConnectionException;
use WcMipConnector\Repository\BrandRepository;
use WcMipConnector\Service\WoocommerceApiConnectionService;

class BrandManager
{
    private const ENDPOINT = 'products/attributes/';
    private const ENDPOINT_BATCH = '/terms/batch/';

    /** @var BrandRepository */
    protected $repository;
    /** @var WoocommerceApiConnectionService */
    protected $apiConnection;

    /** BrandManager constructor. */
    public function __construct()
    {
        $this->apiConnection = new WoocommerceApiConnectionService();
        $this->repository = new BrandRepository();
    }

    /**
     * @param array $brandMapIds
     *
     * @return array
     */
    public function findByBrandShopIdsIndexedByBrandId(array $brandMapIds): array
    {
        return $this->repository->findByBrandShopIdsIndexedByBrandId($brandMapIds);
    }

    /**
     * @param int $brandId
     * @param array $brandRequest
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function save(int $brandId, array $brandRequest): array
    {
        return $this->apiConnection->post(self::ENDPOINT.$brandId.self::ENDPOINT_BATCH, $brandRequest);
    }

    /**
     * @param array $brandData
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function create(array $brandData): array
    {
        return $this->apiConnection->post(self::ENDPOINT, $brandData);
    }

    /**
     * @param int $brandId
     *
     * @return \stdClass|null
     */
    public function findById(int $brandId)
    {
        return $this->repository->findById($brandId);
    }
}