<?php

namespace WcMipConnector\Manager;

defined('ABSPATH') || exit;

use WcMipConnector\Exception\WooCommerceApiConnectionException;
use WcMipConnector\Service\WoocommerceApiConnectionService;
use WcMipConnector\Repository\CategoryRepository;
use WcMipConnector\Model\CategoryReport;

class CategoryManager
{
    private const END_POINT_BATCH = 'products/categories/batch/';

    /** @var WoocommerceApiConnectionService */
    protected $apiConnection;
    /** @var CategoryRepository */
    protected $repository;

    public function __construct()
    {
        $this->apiConnection = new WoocommerceApiConnectionService();
        $this->repository = new CategoryRepository();
    }

    /**
     * @param array $categoryMapIds
     *
     * @return array
     */
    public function findByCategoryShopIdsIndexedByCategoryId(array $categoryMapIds): array
    {
        return $this->repository->findByCategoryShopIdsIndexedByCategoryId($categoryMapIds);
    }

    /**
     * @param array $categoryShopIds
     *
     * @return array
     */
    public function findParentsShopIdsIndexedByShopId(array $categoryShopIds): array
    {
        return $this->repository->findParentsShopIdsIndexedByShopId($categoryShopIds);
    }

    /**
     * @param array $categoryData
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function save(array $categoryData): array
    {
        return $this->apiConnection->post(self::END_POINT_BATCH, $categoryData);
    }

    /**
     * @return CategoryReport
     */
    public function getCategoryReport(): CategoryReport
    {
        $response = new CategoryReport();

        $totalCategories = $this->repository->getTotalCategories();
        $response->TotalCategories = (int)$totalCategories['total'];
        $activeCategories = $this->repository->getActiveCategories();
        $response->ActiveCategories = (int)$activeCategories['active'];
        $response->Categories = $this->repository->getCategories();

        return $response;
    }
}