<?php

namespace WcMipConnector\Manager;

defined('ABSPATH') || exit;

use WcMipConnector\Repository\OAuthRepository;

class OAuthManager
{
    private const DESCRIPTION = 'MIP API';
    private const PERMISSIONS = 'read_write';

    /** @var OAuthRepository */
    private $repository;

    public function __construct()
    {
        $this->repository = new OAuthRepository();
    }

    public function createApiCredentials(string $consumerKey, string $consumerSecret): bool
    {
        $data = [
            'user_id'         => get_current_user_id(),
            'description'     => self::DESCRIPTION,
            'permissions'     => self::PERMISSIONS,
            'consumer_key'    => wc_api_hash($consumerKey),
            'consumer_secret' => $consumerSecret,
            'truncated_key'   => substr($consumerKey,-7),
        ];

        if ($this->repository->insert($data)) {
            return  $this->repository->updatePluginCredentials(
                $consumerKey,
                $consumerSecret
            );
        }

        return false;
    }

    /**
     * @return bool
     */
    public function checkIfExistsApiAccess(): bool
    {
        $data = [
            'user_id'         => get_current_user_id(),
            'description'     => self::DESCRIPTION,
            'permissions'     => self::PERMISSIONS,
            'consumer_secret' => get_option('WC_MIPCONNECTOR_SECRET_KEY'),
            'truncated_key'   => substr(get_option('WC_MIPCONNECTOR_ACCESS_TOKEN'),-7),
        ];

        return !empty($this->repository->checkIfExistsApiAccess($data));
    }
}