<?php

namespace WcMipConnector\Manager;

defined('ABSPATH') || exit;

use WcMipConnector\Exception\WooCommerceApiConnectionException;
use WcMipConnector\Repository\OrderLogRepository;
use WcMipConnector\Service\WoocommerceApiConnectionService;

class OrderManager
{
    private const ORDER_ENDPOINT = 'orders';
    private const ORDER_NOTE_ENDPOINT = 'notes';

    /** @var WoocommerceApiConnectionService */
    protected $apiConnection;

    protected $orderLogRepository;

    public function __construct()
    {
        $this->apiConnection = new WoocommerceApiConnectionService();
        $this->orderLogRepository = new OrderLogRepository();
    }

    /**
     * @param int $orderId
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function getOrderByOrderId(int $orderId): array
    {
        return json_decode(json_encode($this->apiConnection->get(self::ORDER_ENDPOINT.'/'.$orderId)), true);
    }

    /**
     * @param array $order
     * @return array
     */
    public function update(array $order): array
    {
        return json_decode(json_encode($this->apiConnection->put(self::ORDER_ENDPOINT.'/'.(int)$order['id'], $order)), true);
    }

    /**
     * @param array $order
     * @param array $orderNote
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function addOrderNote(array $order, array $orderNote): array
    {
        return json_decode(json_encode($this->apiConnection->post(self::ORDER_ENDPOINT.'/'.(int)$order['id'].'/'.self::ORDER_NOTE_ENDPOINT, $orderNote)), true);
    }
}