<?php

namespace WcMipConnector\Manager;

defined('ABSPATH') || exit;

use WcMipConnector\Exception\WooCommerceApiConnectionException;
use WcMipConnector\Repository\ProductRepository;
use WcMipConnector\Service\WoocommerceApiConnectionService;
use WcMipConnector\Model\ProductReport;

class ProductManager
{
    private const PRODUCT_END_POINT = 'products/batch';

    /** @var ProductRepository */
    protected $productRepository;
    /** @var WoocommerceApiConnectionService */
    protected $apiConnectionService;

    public function __construct()
    {
        $this->productRepository = new ProductRepository();
        $this->apiConnectionService = new WoocommerceApiConnectionService();
    }

    /**
     * @param array $productMapIds
     *
     * @return array
     */
    public function findByProductShopIdsIndexedByProductId(array $productMapIds): array
    {
        return $this->productRepository->findByProductShopIdsIndexedByProductId($productMapIds);
    }

    /**
     * @param array $productMapIds
     *
     * @return array
     */
    public function findProductsNotMappedIndexedBySku(array $productMapIds): array
    {
        return $this->productRepository->findProductsNotMappedIndexedBySku($productMapIds);
    }

    /**
     * @param array $productMapIds
     *
     * @return array
     */
    public function findProductIdAndSkuByProductIds(array $productMapIds): array
    {
        return $this->productRepository->findProductIdAndSkuByProductIds($productMapIds);
    }
    
    /**
     * @param array $products
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function save(array $products): array
    {
        return $this->apiConnectionService->post(self::PRODUCT_END_POINT, $products);
    }

    /**
     * @return ProductReport
     */
    public function getProductReport(): ProductReport
    {
        $response = new ProductReport();

        $totalProducts = $this->productRepository->getTotalProducts();
        $response->TotalProducts = (int)$totalProducts['total'];
        $activeProducts = $this->productRepository->getActiveProducts();
        $response->ActiveProducts = (int)$activeProducts['totalActive'];
        $response->Products = $this->productRepository->getProducts();

        return $response;
    }

    /**
     * @param array $mappedProductsIndexedByShopId
     * @return array
     */
    public function getProductUrls(array $mappedProductsIndexedByShopId): array
    {
        if (empty($mappedProductsIndexedByShopId)) {
            return [];
        }

        return $this->productRepository->getProductUrls($mappedProductsIndexedByShopId);
    }

    /**
     * @param array $mappedProductsIndexedByShopId
     * @return array
     */
    public function getProductImages(array $mappedProductsIndexedByShopId): array
    {
        if (empty($mappedProductsIndexedByShopId)) {
            return [];
        }

        return $this->productRepository->getProductImages($mappedProductsIndexedByShopId);
    }
}