<?php

namespace WcMipConnector\Manager;

defined('ABSPATH') || exit;

use WcMipConnector\Enum\MipWcConnector;
use WcMipConnector\Repository\SystemRepository;

class SystemManager
{
    private const ORDER_CONTROLLER_URL = '/wcmipconnector/api/order';
    private const MIP_CONNECTOR = 'mipconnector';

    /** @var SystemRepository */
    private $repository;

    /** @var \wpdb */
    private $wpDb;

    public function __construct()
    {
        global $wpdb;
        $this->repository = new SystemRepository();
        $this ->wpDb = $wpdb;
    }

    /**
     * @throws \Exception
     */
    public function installMipConnector(): void
    {
        $mipTables = $this->getMipTablesFromDatabase();
        $this->repository->createWcMipConnectorTables($mipTables);
        $this->repository->createWcMipConnectorOptions();

        if(!$this->repository->findWebHookByName('MIP_ORDER_ADD')) {
            $webhook = new \WC_Webhook();
            $webhook->set_name('MIP_ORDER_ADD');
            $webhook->set_user_id(get_current_user_id());
            $webhook->set_status( 'active');
            $webhook->set_topic('order.created');
            $webhook->set_delivery_url(get_home_url().self::ORDER_CONTROLLER_URL);
            $webhook->set_secret(wp_generate_password(50, true, true));
            $webhook->set_api_version('wp_api_v3');
            $webhook->set_pending_delivery(0);
            $webhook->save();
        }

        if(!$this->repository->findWebHookByName('MIP_ORDER_UPDATE')) {
            $webhook = new \WC_Webhook();
            $webhook->set_name('MIP_ORDER_UPDATE');
            $webhook->set_user_id(get_current_user_id());
            $webhook->set_status( 'active');
            $webhook->set_topic('order.updated');
            $webhook->set_delivery_url(get_home_url().self::ORDER_CONTROLLER_URL);
            $webhook->set_secret(wp_generate_password(50, true, true));
            $webhook->set_api_version('wp_api_v3');
            $webhook->set_pending_delivery(0);
            $webhook->save();
        }
    }

    public function uninstallMipConnector(): void
    {
        $this->repository->deleteWcMipConnectorTables();
        $this->repository->deleteWcMipConnectorOptions();

        $filter = [
            'name' => 'MIP_ORDER_ADD',
        ];
        $this->repository->deleteWebHooks($filter);

        $filter = [
            'name' => 'MIP_ORDER_UPDATE',
        ];
        $this->repository->deleteWebHooks($filter);
    }

    /**
     * @return array
     */
    public function getMipTablesFromDatabase(): array
    {
        $mipTables = [];
        $mipTablesResponse = $this ->wpDb->get_results("SHOW TABLES LIKE '%".self::MIP_CONNECTOR."%'");
        foreach ($mipTablesResponse as $tables){
            foreach ($tables as $table) {
                $mipTables[$table] = $table;
            }
        }

        return $mipTables;
    }

    /**
     * @return string
     */
    public function getModuleVersion(): string
    {
        return $this->repository->getModuleVersion();
    }

    /**
     * @param string $moduleVersion
     *
     * @return bool
     */
    public function updateModuleVersion(string $moduleVersion): bool
    {
        return $this->repository->updateModuleVersion($moduleVersion);
    }

    /**
     * @param int $brandId
     *
     * @return bool
     */
    public function updateBrandAttributeId(int $brandId): bool
    {
        return $this->repository->updateBrandAttributeId($brandId);
    }

    /**
     * @return int
     */
    public function getBrandAttributeId(): int
    {
        return $this->repository->getBrandAttributeId();
    }

    public function resetFailureCount(): bool
    {
        $data = [
            'failure_count' => 0,
        ];

        $filter = [
            'name' => 'MIP_ORDER_ADD',
            'name' => 'MIP_ORDER_UPDATE',
        ];

        return $this->repository->resetFailureCount($data, $filter);
    }

    public function executeSql(string $sql): bool
    {
        return $this->repository->executeSql($sql);
    }

    /**
     * @return string
     */
    public function getWoocommerceDefaultCountryIsoCode(): string
    {
        return $this->repository->getWoocommerceDefaultCountryIsoCode();
    }
}