<?php

namespace WcMipConnector\Manager;

defined('ABSPATH') || exit;

use WcMipConnector\Exception\WooCommerceApiConnectionException;
use WcMipConnector\Service\WoocommerceApiConnectionService;
use WcMipConnector\Repository\TagRepository;

class TagManager
{
    private const END_POINT_BATCH = 'products/tags/batch/';
    private const END_POINT = 'products/tags/';

    /** @var WoocommerceApiConnectionService */
    protected $apiConnection;
    /** @var TagRepository */
    protected $repository;
    /** @var TagRepository */
    protected $tagMapManager;

    public function __construct()
    {
        $this->apiConnection = new WoocommerceApiConnectionService();
        $this->repository = new TagRepository();
        $this->tagMapManager = new TagMapManager();
    }

    /**
     * @param array $tagMapIds
     *
     * @return array
     */
    public function findByTagShopIdsIndexedByTagId(array $tagMapIds): array
    {
        return $this->repository->findByTagShopIdsIndexedByTagId($tagMapIds);
    }

    /**
     * @param array $tagData
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function save(array $tagData): array
    {
        return $this->apiConnection->post(self::END_POINT_BATCH, $tagData);
    }

    /**
     * @param array $tagData
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function delete(array $tagData): array
    {
        return $this->apiConnection->post(self::END_POINT_BATCH, $tagData);
    }

    /**
     * @param string $name
     */
    public function deleteByName(string $name): void
    {
        $tagId = $this->repository->findByName($name);
        if ($tagId){
            $this->tagMapManager->delete($tagId);
            $this->apiConnection->delete(self::END_POINT . $tagId, ['force' => true]);
        }
    }
}