<?php

namespace WcMipConnector\Manager;

defined('ABSPATH') || exit;

use WcMipConnector\Service\WoocommerceApiConnectionService;
use WcMipConnector\Repository\VariationRepository;
use WcMipConnector\Model\VariationReport;

class VariationManager
{
    /** @var WoocommerceApiConnectionService */
    protected $apiConnectionService;
    /** @var VariationRepository */
    protected $repository;

    private const PRODUCT_END_POINT = 'products/';
    private const VARIATIONS_END_POINT = '/variations/batch';

    public function __construct()
    {
        $this->apiConnectionService = new WoocommerceApiConnectionService();
        $this->repository = new VariationRepository();
    }

    /**
     * @param array $variationMapIds
     *
     * @return array
     */
    public function findByVariationMapIdsIndexedByVariationId(array $variationMapIds): array
    {
        return $this->repository->findByVariationMapIdsIndexedByVariationId($variationMapIds);
    }

    /**
     * @param array $variationRequest
     * @param int $variationParentId
     *
     * @return array
     */
    public function save(array $variationRequest, int $variationParentId): array
    {
        return $this->apiConnectionService->post(self::PRODUCT_END_POINT . $variationParentId . self::VARIATIONS_END_POINT, $variationRequest);
    }

    /**
     * @return VariationReport
     */
    public function getVariationReport(): VariationReport
    {
        $response = new VariationReport();

        $totalProducts = $this->repository->getTotalVariations();
        $response->TotalProductVariations = (int)$totalProducts['total'];
        $activeProducts = $this->repository->getActiveVariations();
        $response->ActiveProductVariations = (int)$activeProducts['totalActive'];
        $response->ProductVariations = $this->repository->getVariations();

        return $response;
    }
}