<?php

namespace WcMipConnector\Manager;

defined('ABSPATH') || exit;

use WcMipConnector\Service\WoocommerceApiConnectionService;
use WcMipConnector\Controller\ApiController;
use WcMipConnector\Exception\WooCommerceApiConnectionException;

class ZoneManager
{
    private const API_ZONES = 'shipping/zones';
    private const METHOD_ZONE_AVAILABLE = 'shipping/zones/';
    private const METHOD = '/methods';

    /** @var WoocommerceApiConnectionService */
    protected $apiConnection;
    /** @var ApiController */
    protected $apiController;
    /** @var ApiController */
    protected $taxesManager;

    public function __construct()
    {
        $this->apiConnection = new WoocommerceApiConnectionService();
        $this->apiController = new ApiController();
        $this->taxesManager = new TaxesManager();
    }

    /**
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function findAllZones(): array
    {
        return $this->apiConnection->get(self::API_ZONES);
    }

    /**
     * @param array $zonesIndexedById
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function createZones(array $zonesIndexedById): array
    {
        return $this->apiConnection->post(self::API_ZONES, $zonesIndexedById);
    }

    /**
     * @param int $zoneId
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function findShippingZoneByZoneId(int $zoneId): array
    {
        return $this->apiConnection->get(self::METHOD_ZONE_AVAILABLE . $zoneId. self::METHOD);
    }

    /**
     * @param int   $zoneId
     * @param array $shippingZone
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function createShippingZones(int $zoneId, array $shippingZone): array
    {
        return $this->apiConnection->post(self::METHOD_ZONE_AVAILABLE . $zoneId. self::METHOD, $shippingZone);
    }

    /**
     * @param int $zoneId
     * @param int $methodId
     * @return array
     */
    public function enableShippingZoneMethodByZoneIdAndMethodId(int $zoneId, int $methodId): array
    {
        $data = [
            'enabled' => true
        ];

        return json_decode(json_encode($this->apiConnection->put(self::METHOD_ZONE_AVAILABLE.$zoneId.self::METHOD.'/'.$methodId, $data)), true);
    }
}