<?php

namespace WcMipConnector\Repository;

defined('ABSPATH') || exit;

class CategoryMapRepository
{
    private const TABLE_NAME = 'mipconnector_category_map';

    protected $woocommerceClass;
    protected $tableName;

    public function __construct()
    {
        global $wpdb;
        $this->woocommerceClass = $wpdb;
        $this->tableName = $this->woocommerceClass->prefix.self::TABLE_NAME;
    }

    /**
     * @param array $categoriesIdToProcess
     *
     * @return array
     */
    public function findAllIndexedByCategoryMapId(array $categoriesIdToProcess): array
    {
        if (empty($categoriesIdToProcess)){
            return [];
        }

        $sql = 'SELECT category_id, category_shop_id FROM '.$this->tableName.' WHERE category_id IN ('.implode(',',$categoriesIdToProcess).')';

        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'category_shop_id', 'category_id');
    }

    /**
     * @param array $categoriesIdToProcess
     *
     * @return array
     */
    public function findVersionIndexedByCategoryMapId(array $categoriesIdToProcess): array
    {
        if (empty($categoriesIdToProcess)){
            return [];
        }

        $sql = 'SELECT category_id, version FROM '.$this->tableName.' WHERE category_id IN ('.implode(',',$categoriesIdToProcess).')';

        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'version', 'category_id');
    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function save(array $data): bool
    {
        return $this->woocommerceClass->insert($this->tableName, $data);
    }

    /**
     * @param array $data
     * @param array $filter
     *
     * @return bool
     */
    public function update(array $data, array $filter): bool
    {
        return $this->woocommerceClass->update($this->tableName, $data, $filter);
    }

    /**
     * @param string $categoryIdList
     * @return int
     */
    public function deleteByCategoryIds(string $categoryIdList): int
    {
        $sql = 'DELETE FROM '.$this->tableName.' WHERE category_id IN ('.$categoryIdList.');';

        return $this->woocommerceClass->query($sql);
    }
}
