<?php

namespace WcMipConnector\Repository;

defined('ABSPATH') || exit;

class CategoryRepository
{
    private const TABLE_TERMS = 'terms';
    private const TABLE_TAXONOMY = 'term_taxonomy';
    private const CATEGORY_MAP_TABLE = 'mipconnector_category_map';

    /**@var \wpdb */
    protected $woocommerceClass;
    /**@var string */
    protected $tableTerms;
    /**@var string */
    protected $tableTaxonomy;
    /**@var string */
    protected $categoryMapTable;

    public function __construct()
    {
        global $wpdb;
        $this->woocommerceClass = $wpdb;
        $this->tableTerms = $this->woocommerceClass->prefix.self::TABLE_TERMS;
        $this->tableTaxonomy = $this->woocommerceClass->prefix.self::TABLE_TAXONOMY;
        $this->categoryMapTable = $this->woocommerceClass->prefix.self::CATEGORY_MAP_TABLE;
    }

    /**
     * @param array $categoryShopIds
     *
     * @return array
     */
    public function findByCategoryShopIdsIndexedByCategoryId(array $categoryShopIds): array
    {
        if (empty($categoryShopIds)){
            return [];
        }

        $sql = 'SELECT term_id FROM '.$this->tableTerms.' WHERE term_id IN ('.implode(',',$categoryShopIds).')';
        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'term_id', 'term_id');
    }

    /**
     * @param array $categoryShopIds
     *
     * @return array
     */
    public function findParentsShopIdsIndexedByShopId(array $categoryShopIds): array
    {
        if (empty($categoryShopIds)){
            return [];
        }

        $sql = 'SELECT term_id, parent FROM '.$this->tableTaxonomy.' WHERE term_id IN ('.implode(',',$categoryShopIds).')';
        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'parent', 'term_id');
    }

    /**
     * @return array
     */
    public function getTotalCategories(): array
    {
        $sql = 'SELECT COUNT(*) AS total FROM '.$this->categoryMapTable;

        return $this->woocommerceClass->get_row($sql, ARRAY_A);
    }

    /**
     * @return array
     */
    public function getActiveCategories(): array
    {
        $sql = 'SELECT COUNT(*) AS active FROM '.$this->categoryMapTable.' cm
        INNER JOIN '.$this->tableTerms.' ct ON cm.category_shop_id = ct.term_id';

        return $this->woocommerceClass->get_row($sql, ARRAY_A);
    }

    /**
     * @return array
     */
    public function getCategories(): array
    {
        $sql = 'SELECT cm.category_id AS CategoryID, 1 AS Active FROM '.$this->categoryMapTable.' cm INNER JOIN '.$this->tableTerms.' ct ON ct.term_id = cm.category_shop_id';

        return $this->woocommerceClass->get_results($sql, ARRAY_A);
    }
}