<?php

namespace WcMipConnector\Repository;

defined('ABSPATH') || exit;

use WcMipConnector\Manager\FileLogManager;
use WcMipConnector\Model\FileReport;

class FileLogRepository
{
    private const TABLE_NAME = 'mipconnector_file_log';
    private const PRODUCT_IMPORT_PROCESS_TABLE = 'mipconnector_import_process_product';

    protected $woocommerceClass;
    protected $tableName;

    public function __construct()
    {
        global $wpdb;
        $this->woocommerceClass = $wpdb;
        $this->tableName = $this->woocommerceClass->prefix.self::TABLE_NAME;
    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function insert(array $data): bool
    {
        return $this->woocommerceClass->insert($this->tableName, $data);
    }

    /**
     * @param array $data
     * @param array $filter
     *
     * @return bool
     */
    public function update(array $data, array $filter): bool
    {
        return $this->woocommerceClass->update($this->tableName, $data, $filter);
    }

    /**
     * @return \stdClass|null
     */
    public function getFileWithoutProcess(): ?array
    {
        $sql = 'SELECT `file_id`, `name`, `version` FROM '.$this->tableName.' WHERE date_process IS NULL AND date_processing_start IS NULL AND in_process = '.FileLogManager::FILE_NOT_IN_PROCESS.' LIMIT 1';

        return $this->woocommerceClass->get_row($sql, ARRAY_A);
    }

    /**
     * @return bool
     */
    public function getFileInProcess(): bool
    {
        $in_process = FileLogManager::FILE_NOT_IN_PROCESS;
        $sql = 'SELECT in_process AS in_process FROM '.$this->tableName.' WHERE in_process = '.FileLogManager::FILE_IN_PROCESS;

        $result = $this->woocommerceClass->get_row($sql);
        if (empty($result->in_process)) {
            return $in_process;
        }

        $in_process = FileLogManager::FILE_IN_PROCESS;

        return $in_process;
    }

    /**
     * @param int $day
     *
     * @return array
     */
    public function getFileLogNameByDay(int $day): array
    {
        return $this->woocommerceClass->get_results('SELECT `name` FROM '.$this->tableName.' 
            WHERE date_process < (NOW() - INTERVAL '.$day.' DAY) LIMIT 1000', ARRAY_A);
    }

    /**
     * @param array $fileName
     *
     * @return bool
     */
    public function deleteFileLogByFileName(array $fileName): bool
    {
        return $this->woocommerceClass->delete($this->tableName, $fileName);
    }

    /**
     * @param string $fileName
     *
     * @return array|null
     */
    public function getByName(string $fileName): ?array
    {
        $sql = 'SELECT `file_id`, `name`, `version` FROM '.$this->tableName.' WHERE name = \''.$fileName.'\' LIMIT 1';

        return $this->woocommerceClass->get_row($sql, ARRAY_A);
    }

    /**
     * @return array|null
     */
    public function checkForLockedFile(): ?array
    {
        $sql = 'SELECT 
                file_log.file_id AS file_id,
                file_log.date_processing_start, 
                MAX(import_process.date_add) AS last_add, 
                MAX(import_process.date_update) AS last_update
            FROM '.$this->tableName.' file_log
            LEFT JOIN '.$this->woocommerceClass->prefix.self::PRODUCT_IMPORT_PROCESS_TABLE.' import_process ON file_log.file_id = import_process.file_id
            WHERE 
                file_log.in_process = 1
            GROUP BY file_log.file_id
            HAVING (GREATEST(COALESCE(last_add, last_update), COALESCE(last_update, last_add)) < (NOW() - INTERVAL 5 MINUTE))
                OR (file_log.date_processing_start < (NOW() - INTERVAL 10 MINUTE));';

        return $this->woocommerceClass->get_results($sql, ARRAY_A);
    }

    /**
     * @return int
     * @throws \Exception
     */
    public function getTotalFilesCount(): int
    {
        $totalFiles = 'SELECT COUNT(*) AS totalFiles FROM ' .$this->tableName;
        $result = $this->woocommerceClass->get_row($totalFiles);

        return (int)$result->totalFiles;
    }

    /**
     * @return int
     * @throws \Exception
     */
    public function getPendingFilesCount(): int
    {
        $pendingFiles = 'SELECT COUNT(*) AS pendingFiles FROM ' .$this->tableName. ' WHERE date_process IS NULL AND date_processing_start IS NULL';
        $result = $this->woocommerceClass->get_row($pendingFiles);

        return (int)$result->pendingFiles;
    }

    /**
     * @return int
     * @throws \Exception
     */
    public function getProcessingFilesCount(): int
    {
        $processingFiles = 'SELECT COUNT(*) AS processingFiles FROM ' .$this->tableName .' WHERE in_process = 1';
        $result = $this->woocommerceClass->get_row($processingFiles);

        return (bool)$result->processingFiles;
    }

    /**
     * @return string
     * @throws \Exception
     */
    public function getLastStartTime(): string
    {
        $lastStartTime = 'SELECT MAX(date_processing_start) AS max_date_processing_start FROM ' .$this->tableName;
        $result = $this->woocommerceClass->get_row($lastStartTime);

        return (string)$result->max_date_processing_start;
    }

    /**
     * @return string
     * @throws \Exception
     */
    public function getLastAddTime(): string
    {
        $lastAddTime = 'SELECT MAX(date_add) AS max_date_add FROM ' .$this->tableName;
        $result = $this->woocommerceClass->get_row($lastAddTime);

        return (string)$result->max_date_add;

    }
}

