<?php

namespace WcMipConnector\Repository;

defined('ABSPATH') || exit;

class ProductMapRepository
{
    private const TABLE_NAME = 'mipconnector_product_map';

    /** @var \wpdb */
    protected $woocommerceClass;
    /** @var string */
    private $tableName;

    public function __construct()
    {
        global $wpdb;
        $this->woocommerceClass = $wpdb;
        $this->tableName = $this->woocommerceClass->prefix.self::TABLE_NAME;
    }

    /**
     * @param array $productMapIds
     *
     * @return array
     */
    public function findByProductMapIdsIndexedByProductMapId(array $productMapIds): array
    {
        if (empty($productMapIds)){
            return [];
        }

        $sql = 'SELECT product_id, product_shop_id FROM '.$this->tableName.' WHERE product_id IN ('.implode(',',$productMapIds).')';
        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'product_shop_id', 'product_id');

    }

    /**
     * @param array $productMapIds
     *
     * @return array
     */
    public function findVersionsIndexedByProductMapId(array $productMapIds): array
    {
        if (empty($productMapIds)){
            return [];
        }

        $sql = 'SELECT product_id, version FROM '.$this->tableName.' WHERE product_id IN ('.implode(',',$productMapIds).')';
        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'version', 'product_id');

    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function save(array $data): bool
    {
        return $this->woocommerceClass->insert($this->tableName, $data);
    }

    /**
     * @param array $data
     * @param array $filter
     *
     * @return bool
     */
    public function update(array $data, array $filter): bool
    {
        return $this->woocommerceClass->update($this->tableName, $data, $filter);
    }

    /**
     * @return array
     */
    public function getProductsShopIndexedByProductShopId(): array
    {
        $sql = 'SELECT pm.product_shop_id FROM '.$this->tableName.' pm';
        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'product_shop_id', 'product_shop_id');
    }

    /**
     * @param string $table
     * @param array $data
     * @return bool|int
     */
    public function updateProductsUrl(string $table, array $data)
    {
        return $this->woocommerceClass->replace($table, $data);
    }

    /**
     * @param string $table
     * @param array $data
     * @return bool|int
     */
    public function updateImagesUrl(string $table, array $data)
    {
        return $this->woocommerceClass->replace($table, $data);
    }

    /**
     * @param string $table
     * @param array $data
     * @return bool|int
     */
    public function updateProductImageUrl(string $table, array $data)
    {
        return $this->woocommerceClass->replace($table, $data);
    }

    /**
     * @param string $tables
     * @return bool|int
     */
    public function cleanProductImagesUrls(string $tables)
    {
       return $this->woocommerceClass->query($tables);
    }
}