<?php

namespace WcMipConnector\Repository;

defined('ABSPATH') || exit;

class ProductRepository
{
    private const TABLE_NAME = 'wc_product_meta_lookup';
    private const PRODUCT_MAP = 'mipconnector_product_map';
    private const POST_STATUS = "'publish'";
    private const POST_TABLE = 'posts';

    /** @var \wpdb */
    protected $woocommerceClass;
    /** @var string */
    private $tableName;
    /** @var string */
    private $productMapTable;
    /** @var string */
    private $postTable;

    public function __construct()
    {
        global $wpdb;
        $this->woocommerceClass = $wpdb;
        $this->tableName = $this->woocommerceClass->prefix.self::TABLE_NAME;
        $this->productMapTable = $this->woocommerceClass->prefix.self::PRODUCT_MAP;
        $this->postTable = $this->woocommerceClass->prefix.self::POST_TABLE;
    }

    /**
     * @param array $productShopIds
     *
     * @return array
     */
    public function findByProductShopIdsIndexedByProductId(array $productShopIds): array
    {
        if (empty($productShopIds)) {
            return [];
        }

        $sql = 'SELECT product_id FROM '.$this->tableName.' WHERE product_id IN ('.implode(',', $productShopIds).')';
        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'product_id', 'product_id');
    }

    /**
     * @param array $productShopIds
     *
     * @return array
     */
    public function findProductsNotMappedIndexedBySku(array $productShopIds): array
    {
        if (empty($productShopIds)) {
            return [];
        }

        $sql = 'SELECT product_id, sku FROM '.$this->tableName.' WHERE sku IN ("'.implode('","', $productShopIds).'")';
        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'product_id', 'sku');
    }

    /**
     * @return array
     */
    public function getTotalProducts(): array
    {
        $sql = 'SELECT COUNT(*) AS total FROM '.$this->productMapTable;

        return $this->woocommerceClass->get_row($sql, ARRAY_A);
    }

    /**
     * @return array
     */
    public function getActiveProducts(): array
    {
        $sql = 'SELECT COUNT(*) AS totalActive FROM '.$this->productMapTable.' pm
            INNER JOIN '.$this->postTable.' pa ON pm.product_shop_id = pa.ID
            WHERE pa.post_status = '.self::POST_STATUS;

        return $this->woocommerceClass->get_row($sql, ARRAY_A);
    }

    /**
     * @return array
     */
    public function getProducts(): array
    {
        $sql = 'SELECT DISTINCT(pm.product_id) AS ProductID, p.sku AS SKU, pa.post_status AS Active, p.stock_quantity AS Stock
            FROM '.$this->productMapTable.' pm 
            INNER JOIN '.$this->tableName.' p ON p.product_id = pm.product_shop_id 
            INNER JOIN '.$this->postTable.' pa ON pm.product_shop_id = pa.ID';

        return $this->woocommerceClass->get_results($sql, ARRAY_A);
    }

    /**
     * @param array $productShopIds
     *
     * @return array
     */
    public function findProductIdAndSkuByProductIds(array $productShopIds): array
    {
        if (empty($productShopIds)) {
            return [];
        }

        $sql = 'SELECT product_id, sku FROM '.$this->tableName.' WHERE product_id IN ("'.implode('","', $productShopIds).'")';
        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'sku', 'product_id');
    }

    /**
     * @param array $productShopIds
     * @return array
     */
    public function getProductUrls(array $productShopIds): array
    {
        if (empty($productShopIds)) {
            return [];
        }

        $sql = 'SELECT p.guid, p.ID FROM '.$this->postTable.' p WHERE p.ID IN ("'.implode('","', $productShopIds).'")';

        return $this->woocommerceClass->get_results($sql, ARRAY_A);
    }

    /**
     * @param array $productShopIds
     * @return array
     */
    public function getProductImages(array $productShopIds): array
    {
        if (empty($productShopIds)) {
            return [];
        }

        $sql = 'SELECT p.post_parent, p.guid, p.ID
                FROM '.$this->postTable.' p 
                WHERE p.post_parent IN ("'.implode('","', $productShopIds).'") 
                AND p.post_status = "inherit" and p.post_mime_type LIKE "%image%"';

        return $this->woocommerceClass->get_results($sql, ARRAY_A);
    }
}