<?php

namespace WcMipConnector\Repository;

use WcMipConnector\Enum\MipWcConnector;

defined('ABSPATH') || exit;

require_once ABSPATH.'wp-admin/includes/upgrade.php';

class SystemRepository
{
    private const WEB_HOOKS = 'wc_webhooks';
    private const FILE_LOG_TABLE = 'mipconnector_file_log';
    private const IMPORT_PROCESS_ATTRIBUTE_GROUP = 'mipconnector_import_process_attribute_group';
    private const IMPORT_PROCESS_ATTRIBUTE = 'mipconnector_import_process_attribute';
    private const IMPORT_PROCESS_PRODUCT = 'mipconnector_import_process_product';
    private const IMPORT_PROCESS_VARIATION = 'mipconnector_import_process_variation';
    private const IMPORT_PROCESS_CATEGORY = 'mipconnector_import_process_category';
    private const IMPORT_PROCESS_BRAND = 'mipconnector_import_process_brand';
    private const IMPORT_PROCESS_TAG = 'mipconnector_import_process_tag';
    private const PRODUCT_MAP = 'mipconnector_product_map';
    private const CATEGORY_MAP = 'mipconnector_category_map';
    private const BRAND_MAP = 'mipconnector_brand_map';
    private const VARIATION_MAP = 'mipconnector_variation_map';
    private const TAG_MAP = 'mipconnector_tag_map';
    private const ATTRIBUTE_GROUP_MAP = 'mipconnector_attribute_group_map';
    private const ATTRIBUTE_MAP = 'mipconnector_attribute_map';
    private const ORDER_LOG = 'mipconnector_order_log';
    private const PRODUCT_URL = 'mipconnector_product_url';
    private const IMAGE_URL = 'mipconnector_image_url';
    private const PRODUCT_IMAGE_URL = 'mipconnector_product_image_url';


    public function createWcMipConnectorOptions():void
    {
        $moduleInfo = get_plugin_data(MipWcConnector::MODULE_DIR.'/WcMipconnector.php');

        add_option('WC_MIPCONNECTOR_VERSION', $moduleInfo['Version']);
        add_option('WC_MIPCONNECTOR_ACCESS_TOKEN', '');
        add_option('WC_MIPCONNECTOR_SECRET_KEY', '');
        add_option('WC_MIPCONNECTOR_SEND_EMAIL', '1');
        add_option('WC_MIPCONNECTOR_TAG_ACTIVE', '1');
        add_option('WC_MIPCONNECTOR_TAG_NAME', MipWcConnector::WC_MIPCONNECTOR_TAG_NAME);
        add_option('WC_MIPCONNECTOR_BRAND_ID', '');
        add_option('WC_MIPCONNECTOR_BIGBUY_CARRIER_OPTION', '0');
    }

    /**
     * @param $mipTables
     */
    public function createWcMipConnectorTables($mipTables): void
    {
        dbDelta($this->getWcMipConnectorSchemaTables($mipTables));
        dbDelta($this->getWcMipConnectorSchemaTablesMap($mipTables));
    }

    /**
     * @param $mipTables
     *
     * @return string
     */
    private function getWcMipConnectorSchemaTables($mipTables): string
    {
        global $wpdb;
        $tables = [];
        if (!array_key_exists($wpdb->prefix.self::FILE_LOG_TABLE, $mipTables)){
            $tables[$wpdb->prefix.self::FILE_LOG_TABLE] = "      
            CREATE TABLE {$wpdb->prefix}mipconnector_file_log (
                `file_id` INT(11) NOT NULL AUTO_INCREMENT,
                `name` VARCHAR(255) NULL DEFAULT NULL,
                `version` VARCHAR(12) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_process` DATETIME NULL DEFAULT NULL,
                `date_processing_start` DATETIME NULL DEFAULT NULL,
                `in_process` TINYINT(1) NULL DEFAULT '0',
                PRIMARY KEY (`file_id`),
                INDEX `name` (`name`),
                INDEX `date_process` (`date_process`),
                INDEX `in_process` (`in_process`),
                INDEX `date_add` (`date_add`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::IMPORT_PROCESS_ATTRIBUTE_GROUP, $mipTables)) {
            $tables[$wpdb->prefix.self::IMPORT_PROCESS_ATTRIBUTE_GROUP] = "  
            CREATE TABLE {$wpdb->prefix}mipconnector_import_process_attribute_group (
                `attribute_group_id` INT(11) NOT NULL DEFAULT '0',
                `file_id` INT(11) NOT NULL,
                `response_api` TINYINT(1) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                FOREIGN KEY (`file_id`) REFERENCES {$wpdb->prefix}mipconnector_file_log(`file_id`),
                INDEX `attribute_group_id` (`attribute_group_id`),
                INDEX `file_id` (`file_id`),
                UNIQUE (`attribute_group_id`, `file_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::IMPORT_PROCESS_VARIATION, $mipTables)) {
            $tables[$wpdb->prefix.self::IMPORT_PROCESS_VARIATION] = "
             CREATE TABLE {$wpdb->prefix}mipconnector_import_process_variation (
                `variation_id` INT(11) NOT NULL DEFAULT '0',
                `file_id` INT(11) NOT NULL,
                `response_api` TINYINT(1) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                FOREIGN KEY (`file_id`) REFERENCES {$wpdb->prefix}mipconnector_file_log(`file_id`),
                INDEX `variation_id` (`variation_id`),
                INDEX `file_id` (`file_id`),
                UNIQUE (`variation_id`, `file_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::IMPORT_PROCESS_ATTRIBUTE, $mipTables)) {
            $tables[$wpdb->prefix.self::IMPORT_PROCESS_ATTRIBUTE] = "
            CREATE TABLE {$wpdb->prefix}mipconnector_import_process_attribute (
                `attribute_id` INT(11) NOT NULL DEFAULT '0',
                `file_id` INT(11) NOT NULL,
                `response_api` TINYINT(1) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                FOREIGN KEY (`file_id`) REFERENCES {$wpdb->prefix}mipconnector_file_log(`file_id`),
                INDEX `attribute_id` (`attribute_id`),
                INDEX `file_id` (`file_id`),
                UNIQUE (`attribute_id`, `file_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::IMPORT_PROCESS_CATEGORY, $mipTables)) {
            $tables[$wpdb->prefix.self::IMPORT_PROCESS_CATEGORY] = "
            CREATE TABLE {$wpdb->prefix}mipconnector_import_process_category (
                `category_id` INT(11) NOT NULL DEFAULT '0',
                `file_id` INT(11) NOT NULL,
                `response_api` TINYINT(1) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                FOREIGN KEY (`file_id`) REFERENCES {$wpdb->prefix}mipconnector_file_log(`file_id`),
                INDEX `category_id` (`category_id`),
                INDEX `file_id` (`file_id`),
                UNIQUE (`category_id`, `file_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::IMPORT_PROCESS_BRAND, $mipTables)) {
            $tables[$wpdb->prefix.self::IMPORT_PROCESS_BRAND] = "
            CREATE TABLE {$wpdb->prefix}mipconnector_import_process_brand (
                `brand_id` INT(11) NOT NULL DEFAULT '0',
                `file_id` INT(11) NOT NULL,
                `response_api` TINYINT(1) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                FOREIGN KEY (`file_id`) REFERENCES {$wpdb->prefix}mipconnector_file_log(`file_id`),
                INDEX `brand_id` (`brand_id`),
                INDEX `file_id` (`file_id`),
                UNIQUE (`brand_id`, `file_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::IMPORT_PROCESS_TAG, $mipTables)) {
            $tables[$wpdb->prefix.self::IMPORT_PROCESS_TAG] = "
            CREATE TABLE {$wpdb->prefix}mipconnector_import_process_tag (
                `tag_id` INT(11) NOT NULL DEFAULT '0',
                `file_id` INT(11) NOT NULL,
                `response_api` TINYINT(1) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                FOREIGN KEY (`file_id`) REFERENCES {$wpdb->prefix}mipconnector_file_log(`file_id`),
                INDEX `tag_id` (`tag_id`),
                INDEX `file_id` (`file_id`),
                UNIQUE (`tag_id`, `file_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::IMPORT_PROCESS_PRODUCT, $mipTables)) {
            $tables[$wpdb->prefix.self::IMPORT_PROCESS_PRODUCT] = "
            CREATE TABLE {$wpdb->prefix}mipconnector_import_process_product (
                `product_id` INT(11) NOT NULL DEFAULT '0',
                `file_id` INT(11) NOT NULL,
                `response_api` TINYINT(1) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                FOREIGN KEY (`file_id`) REFERENCES {$wpdb->prefix}mipconnector_file_log(`file_id`),
                INDEX `product_id` (`product_id`),
                INDEX `file_id` (`file_id`),
                UNIQUE (`product_id`, `file_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::ORDER_LOG, $mipTables)) {
            $tables[$wpdb->prefix.self::ORDER_LOG] = "
            CREATE TABLE {$wpdb->prefix}mipconnector_order_log (
                `order_id` INT(11) NOT NULL DEFAULT '0',
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                `date_process` DATETIME NULL DEFAULT NULL,
                PRIMARY KEY (`order_id`),
                INDEX `date_process` (`date_process`),
                INDEX `date_update` (`date_update`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;
        ";
        }

        if (!array_key_exists($wpdb->prefix.self::PRODUCT_URL, $mipTables)) {
            $tables[$wpdb->prefix.self::PRODUCT_URL] = "
            CREATE TABLE {$wpdb->prefix}mipconnector_product_url (
                `product_shop_id` INT(11) UNSIGNED NOT NULL,
	            `iso_code` VARCHAR(10) NULL DEFAULT NULL,
	            `url` VARCHAR(2048) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                PRIMARY KEY (`product_shop_id`),
                INDEX `date_add` (`date_add`),
                INDEX `date_update` (`date_update`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;
        ";
        }

        if (!array_key_exists($wpdb->prefix.self::IMAGE_URL, $mipTables)) {
            $tables[$wpdb->prefix.self::IMAGE_URL] = "
            CREATE TABLE {$wpdb->prefix}mipconnector_image_url (
                `id_image` INT(11) UNSIGNED NOT NULL,
                `cover` INT(11) UNSIGNED NULL DEFAULT NULL,
                `url` VARCHAR(2048) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                PRIMARY KEY (`id_image`),
                INDEX `date_add` (`date_add`),
                INDEX `date_update` (`date_update`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;
        ";
        }

        if (!array_key_exists($wpdb->prefix.self::PRODUCT_IMAGE_URL, $mipTables)) {
            $tables[$wpdb->prefix.self::PRODUCT_IMAGE_URL] = "
            CREATE TABLE {$wpdb->prefix}mipconnector_product_image_url (
                `product_shop_id` INT(11) UNSIGNED NOT NULL,
                `id_image` INT(11) UNSIGNED NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                INDEX `product_shop_id` (`product_shop_id`),
                INDEX `id_image` (`id_image`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;
        ";
        }

        return implode('', $tables);
    }

    /**
     * @param $mipTables
     *
     * @return string
     */
    private function getWcMipConnectorSchemaTablesMap($mipTables): string
    {
        $tables = [];
        global $wpdb;

        if (!array_key_exists($wpdb->prefix.self::PRODUCT_MAP, $mipTables)) {
            $tables[$wpdb->prefix.self::PRODUCT_MAP] = "          
            CREATE TABLE {$wpdb->prefix}mipconnector_product_map (
                `product_id` INT(11) NOT NULL DEFAULT '0',
                `product_shop_id` INT(11) NULL DEFAULT NULL,
                `version` VARCHAR(16000) NULL DEFAULT '{}',
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                PRIMARY KEY (`product_id`),
                INDEX `product_shop_id` (`product_shop_id`),
                UNIQUE (`product_id`),
                UNIQUE (`product_shop_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::BRAND_MAP, $mipTables)) {
            $tables[$wpdb->prefix.self::BRAND_MAP] = "                     
            CREATE TABLE {$wpdb->prefix}mipconnector_brand_map (
                `brand_id` INT(11) NOT NULL DEFAULT '0',
                `brand_shop_id` INT(11) NULL DEFAULT NULL,
                `version` VARCHAR(4096) NULL DEFAULT '0',
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                PRIMARY KEY (`brand_id`),
                INDEX `brand_shop_id` (`brand_shop_id`),
                UNIQUE (`brand_id`),
                UNIQUE (`brand_shop_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::TAG_MAP, $mipTables)) {
            $tables[$wpdb->prefix.self::TAG_MAP] = "  
            CREATE TABLE {$wpdb->prefix}mipconnector_tag_map (
                `tag_id` INT(11) NOT NULL DEFAULT '0',
                `tag_shop_id` INT(11) NULL DEFAULT NULL,
                `version` VARCHAR(16000) NULL DEFAULT NULL,
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                `id_lang` INT(11) NOT NULL DEFAULT '0',
                PRIMARY KEY (`tag_id`, `id_lang`),
                INDEX `tag_shop_id` (`tag_shop_id`),
                INDEX `id_lang` (`id_lang`),
                INDEX `tag_id` (`tag_id`),
                INDEX `id_tag_id_lang` (`tag_id`, `id_lang`),
                UNIQUE (`tag_id`),
                UNIQUE (`tag_shop_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::ATTRIBUTE_GROUP_MAP, $mipTables)) {
            $tables[$wpdb->prefix.self::ATTRIBUTE_GROUP_MAP] = "  
            CREATE TABLE {$wpdb->prefix}mipconnector_attribute_group_map (
            `attribute_group_id` INT(11) NOT NULL DEFAULT '0',
            `attribute_group_shop_id` INT(11) NULL DEFAULT NULL,
            `version` VARCHAR(16000) NULL DEFAULT '{}',
            `date_add` DATETIME NULL DEFAULT NULL,
            `date_update` DATETIME NULL DEFAULT NULL,
            PRIMARY KEY (`attribute_group_id`),
            INDEX `attribute_group_shop_id` (`attribute_group_shop_id`),
                UNIQUE (`attribute_group_id`),
                UNIQUE (`attribute_group_shop_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::VARIATION_MAP, $mipTables)) {
            $tables[$wpdb->prefix.self::VARIATION_MAP] = "  
            CREATE TABLE {$wpdb->prefix}mipconnector_variation_map (
            `variation_id` INT(11) NOT NULL DEFAULT '0',
            `variation_shop_id` INT(11) NULL DEFAULT NULL,
            `date_add` DATETIME NULL DEFAULT NULL,
            `date_update` DATETIME NULL DEFAULT NULL,
            PRIMARY KEY (`variation_id`),
            INDEX `variation_shop_id` (`variation_shop_id`),
            UNIQUE (`variation_id`),
            UNIQUE (`variation_shop_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::ATTRIBUTE_MAP, $mipTables)) {
            $tables[$wpdb->prefix.self::ATTRIBUTE_MAP] = "  
            CREATE TABLE {$wpdb->prefix}mipconnector_attribute_map (
                `attribute_id` INT(11) NOT NULL DEFAULT '0',
                `attribute_shop_id` INT(11) NULL DEFAULT NULL,
                `version` VARCHAR(16000) NULL DEFAULT '{}',
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                PRIMARY KEY (`attribute_id`),
                INDEX `attribute_shop_id` (`attribute_shop_id`),
                UNIQUE (`attribute_id`),
                UNIQUE (`attribute_shop_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;";
        }

        if (!array_key_exists($wpdb->prefix.self::CATEGORY_MAP, $mipTables)) {
            $tables[$wpdb->prefix.self::CATEGORY_MAP] = "  
            CREATE TABLE {$wpdb->prefix}mipconnector_category_map (
                `category_id` INT(11) NOT NULL DEFAULT '0',
                `category_shop_id` INT(11) NULL DEFAULT NULL,
                `version` VARCHAR(16000) NULL DEFAULT '{}',
                `date_add` DATETIME NULL DEFAULT NULL,
                `date_update` DATETIME NULL DEFAULT NULL,
                PRIMARY KEY (`category_id`),
                INDEX `category_shop_id` (`category_shop_id`),
                UNIQUE (`category_id`),
                UNIQUE (`category_shop_id`)
            )
            COLLATE='utf8_general_ci'
            ENGINE=InnoDB;
            ";
        }

        return implode('', $tables);
    }

    public function deleteWcMipConnectorTables(): void
    {
        global $wpdb;

        $wpdb->query($this->getDropTables());
    }

    /**
     * @return bool
     */
    private function getDropTables(): bool
    {
        global $wpdb;

        $tables = "DROP TABLE IF EXISTS
          {$wpdb->prefix}mipconnector_attribute_group_map,
          {$wpdb->prefix}mipconnector_attribute_map,
          {$wpdb->prefix}mipconnector_variation_map,
          {$wpdb->prefix}mipconnector_category_map,
          {$wpdb->prefix}mipconnector_brand_map,
          {$wpdb->prefix}mipconnector_product_map,
          {$wpdb->prefix}mipconnector_order_log,
          {$wpdb->prefix}mipconnector_tag_map,
          {$wpdb->prefix}mipconnector_import_process_attribute_group,
          {$wpdb->prefix}mipconnector_import_process_attribute,
          {$wpdb->prefix}mipconnector_import_process_brand,
          {$wpdb->prefix}mipconnector_import_process_variation,
          {$wpdb->prefix}mipconnector_import_process_tag,
          {$wpdb->prefix}mipconnector_import_process_category,
          {$wpdb->prefix}mipconnector_import_process_product,
          {$wpdb->prefix}mipconnector_product_url,
          {$wpdb->prefix}mipconnector_image_url,
          {$wpdb->prefix}mipconnector_product_image_url,
          {$wpdb->prefix}mipconnector_file_log;";

        return $tables;
    }

    public function deleteWcMipConnectorOptions(): void
    {
        delete_option('WC_MIPCONNECTOR_VERSION');
        delete_option('WC_MIPCONNECTOR_ACCESS_TOKEN');
        delete_option('WC_MIPCONNECTOR_SECRET_KEY');
        delete_option('WC_MIPCONNECTOR_SEND_EMAIL');
        delete_option('WC_MIPCONNECTOR_TAG_ACTIVE');
        delete_option('WC_MIPCONNECTOR_TAG_NAME');
        delete_option('WC_MIPCONNECTOR_BRAND_ID');
        delete_option('WC_MIPCONNECTOR_BIGBUY_CARRIER_OPTION');
    }

    public function deleteWebHooks(array $filter): void
    {
        global $wpdb;

        $wpdb->delete($wpdb->prefix.self::WEB_HOOKS, $filter);
    }

    /**
     * @return string
     */
    public function getModuleVersion(): string
    {
        return get_option('WC_MIPCONNECTOR_VERSION');
    }

    /**
     * @param $moduleVersion
     *
     * @return string
     */
    public function updateModuleVersion(string $moduleVersion): bool
    {
        return update_option('WC_MIPCONNECTOR_VERSION', $moduleVersion);
    }

    /**
     * @return int
     */
    public function getBrandAttributeId(): int
    {
        return (int)get_option('WC_MIPCONNECTOR_BRAND_ID');
    }

    /**
     * @param $brandId
     *
     * @return int
     */
    public function updateBrandAttributeId(int $brandId): bool
    {
        return update_option('WC_MIPCONNECTOR_BRAND_ID', $brandId);
    }

    public function findWebHookByName(string $name): ?array
    {
        global $wpdb;

        $sql = 'SELECT * FROM '.$wpdb->prefix.self::WEB_HOOKS.' WHERE name = "'.$name.'"';

        return $wpdb->get_row($sql, ARRAY_A);
    }

    public function resetFailureCount(array $data, array $filter): ?bool
    {
        global $wpdb;

        return $wpdb->update($wpdb->prefix.self::WEB_HOOKS, $data, $filter);
    }

    public function executeSql(string $sql): bool
    {
        global $wpdb;

        return  $wpdb->query($sql);
    }

    /**
     * @return string
     */
    public function getWoocommerceDefaultCountryIsoCode(): string
    {
        return get_option('woocommerce_default_country');
    }
}