<?php

namespace WcMipConnector\Repository;

defined('ABSPATH') || exit;

class VariationRepository
{
    private const TABLE_NAME = 'wc_product_meta_lookup';
    private const POSTS_TABLE = 'posts';
    private const VARIATION_MAP_TABLE = 'mipconnector_variation_map';
    private const POST_STATUS = "'publish'";

    /** @var \wpdb */
    protected $woocommerceClass;
    /** @var string */
    private $tableName;
    /** @var string */
    private $postTable;
    /** @var string */
    private $variationMapTable;

    public function __construct()
    {
        global $wpdb;
        $this->woocommerceClass = $wpdb;
        $this->tableName = $this->woocommerceClass->prefix.self::TABLE_NAME;
        $this->postTable = $this->woocommerceClass->prefix.self::POSTS_TABLE;
        $this->variationMapTable = $this->woocommerceClass->prefix.self::VARIATION_MAP_TABLE;
    }

    /**
     * @param array $variationShopIds
     *
     * @return array
     */
    public function findByVariationMapIdsIndexedByVariationId(array $variationShopIds): array
    {
        if (empty($variationShopIds)){
            return [];
        }

        $sql = 'SELECT product_id FROM '.$this->tableName.' WHERE product_id IN ('.implode(',',$variationShopIds).')';
        $result = $this->woocommerceClass->get_results($sql, ARRAY_A);

        return array_column($result, 'product_id', 'product_id');
    }

    /**
     * @return array
     */
    public function getTotalVariations(): array
    {
        $sql = 'SELECT COUNT(*) AS total FROM '.$this->variationMapTable;

        return $this->woocommerceClass->get_row($sql, ARRAY_A);
    }

    /**
     * @return array
     */
    public function getActiveVariations(): array
    {
        $sql = 'SELECT COUNT(*) AS totalActive FROM '.$this->variationMapTable.' pm
            INNER JOIN '.$this->postTable.' pa ON pm.variation_shop_id = pa.ID
            WHERE pa.post_status = '.self::POST_STATUS;

        return $this->woocommerceClass->get_row($sql, ARRAY_A);
    }

    /**
     * @return array
     */
    public function getVariations(): array
    {
        $sql = 'SELECT DISTINCT(pm.variation_id) AS ProductVariationID, p.sku AS SKU, pa.post_status AS Active, p.stock_quantity AS Stock
            FROM '.$this->variationMapTable.' pm 
            INNER JOIN '.$this->tableName.' p ON p.product_id = pm.variation_shop_id 
            INNER JOIN '.$this->postTable.' pa ON pm.variation_shop_id = pa.ID';

        return $this->woocommerceClass->get_results($sql, ARRAY_A);
    }
}