<?php

namespace WcMipConnector\Repository;

defined('ABSPATH') || exit;

class WoocommerceApiConnectionRepository
{
    private const ACCESS_TOKEN = 'WC_MIPCONNECTOR_ACCESS_TOKEN';
    private const SECRET_KEY = 'WC_MIPCONNECTOR_SECRET_KEY';
    private const TAG_OPTION = 'WC_MIPCONNECTOR_TAG_ACTIVE';
    private const SEND_EMAIL = 'WC_MIPCONNECTOR_SEND_EMAIL';
    private const BIGBUY_CARRIER_OPTION = 'WC_MIPCONNECTOR_BIGBUY_CARRIER_OPTION';

    protected $woocommerceClass;

    public function __construct()
    {
        global $wpdb;
        $this->woocommerceClass = $wpdb;
    }

    /**
     * @return string
     */
    public function getOptionBySiteUrl(): string
    {
        return home_url();
    }

    /**
     * @return string
     */
    public function getAccessToken(): string
    {
        return get_option(self::ACCESS_TOKEN);
    }

    /**
     * @return string
     */
    public function getSecretKey(): string
    {
        return get_option(self::SECRET_KEY);
    }

    /**
     * @param $access
     */
    public function saveAccessToken($access): void
    {
        update_option(self::ACCESS_TOKEN, $access);
    }

    /**
     * @param $secret
     */
    public function saveSecretKey($secret): void
    {
        update_option(self::SECRET_KEY, $secret);
    }

    /**
     * @param $tagOption
     */
    public function saveBlackFridayOption($tagOption): void
    {
        update_option(self::TAG_OPTION, $tagOption);
    }

    /**
     * @return bool
     */
    public function getTagOption(): bool
    {
        return get_option(self::TAG_OPTION);
    }

    /**
     * @param int $sendEmail
     * @return bool
     */
    public function saveSendEmailConfiguration(int $sendEmail): bool
    {
        return update_option(self::SEND_EMAIL, $sendEmail);
    }

    /**
     * @return bool
     */
    public function getSendEmailConfiguration(): bool
    {
        return get_option(self::SEND_EMAIL);
    }

    /**
     * @return bool
     */
    public function getBigBuyCarrierOption(): bool
    {
        return get_option(self::BIGBUY_CARRIER_OPTION);
    }

    /**
     * @param int $bigbuyCarrierOption
     * @return bool
     */
    public function saveBigBuyCarrierOption(int $bigbuyCarrierOption): bool
    {
        return update_option(self::BIGBUY_CARRIER_OPTION, $bigbuyCarrierOption);
    }
}