<?php

namespace WcMipConnector\Service;

defined('ABSPATH') || exit;

use WcMipConnector\Factory\AttributeGroupFactory;
use WcMipConnector\Manager\AttributeGroupMapManager;
use WcMipConnector\Manager\AttributeGroupManager;
use WcMipConnector\Factory\AttributeGroupMapFactory;

class AttributeGroupService
{
    /** @var AttributeGroupFactory */
    protected $attributeGroupFactory;
    /** @var AttributeGroupMapFactory */
    protected $attributeGroupMapFactory;
    /** @var AttributeGroupMapManager */
    protected $attributeGroupMapManager;
    /** @var AttributeGroupManager */
    protected $attributeGroupManager;
    /** @var ImportProcessAttributeGroupService */
    protected $importProcessService;
    /** @var LoggerService */
    protected $logger;
    /** @var array */
    protected $languages;
    /** @var SystemService */
    protected $systemService;

    public function __construct()
    {
        $this->attributeGroupFactory = new AttributeGroupFactory();
        $this->attributeGroupMapFactory = new AttributeGroupMapFactory();
        $this->attributeGroupMapManager = new AttributeGroupMapManager();
        $this->attributeGroupManager = new AttributeGroupManager();
        $this->importProcessService = new ImportProcessAttributeGroupService();
        $this->logger = new LoggerService();
        $this->systemService = new SystemService();

    }

    /**
     * @param array $attributesGroupIndexedByAttributeGroupMapId
     * @param array $attributesGroup
     * @param int $fileId
     * @param array $languages
     * @return array
     */
    public function processAttributeGroupByBatch(array $attributesGroupIndexedByAttributeGroupMapId, array $attributesGroup, int $fileId, array $languages): array
    {
        $this->languages = $languages;
        $attributeGroupShopIndexedByAttributeGroupId = [];
        $processedArray = [[]];
        $attributeGroupShopIndexedByMapIds = [];

        $batches = array_chunk($attributesGroupIndexedByAttributeGroupMapId, $this->systemService->getBatchValue(), true);

        foreach ($batches as $batchToProcess) {
            $attributeGroupToSaveIndexedByAttributeGroupMapId = [];
            $attributeGroupIdsToUpdateIndexedByAttributeGroupMapId = [];
            $attributeGroupToUpdateIndexedByAttributeGroupMapId = [];
            $attributeGroupFactorySave = [];
            $attributeGroupFactoryToUpdate = [];

            $attributeGroupMapsIndexedByAttributeGroupMapId = $this->attributeGroupMapManager->findByAttributeGroupMapIdsIndexedByAttributeGroupMapId(array_keys($batchToProcess));
            $attributeGroupVersionsIndexedByMapIds = $this->attributeGroupMapManager->findVersionsIndexedByAttributeGroupMapId(array_keys($attributeGroupMapsIndexedByAttributeGroupMapId));

            if(!empty($attributeGroupMapsIndexedByAttributeGroupMapId)){
                $attributeGroupShopIndexedByAttributeGroupId = $this->attributeGroupManager->findByAttributeGroupShopIdsIndexedByAttributeGroupId(array_values($attributeGroupMapsIndexedByAttributeGroupMapId));
            }

            if($attributeGroupShopIndexedByAttributeGroupId){
                foreach ($attributeGroupMapsIndexedByAttributeGroupMapId as $attributeGroupParentMappedId => $attributeGroupMappedId){
                    if(array_key_exists($attributeGroupMappedId, $attributeGroupShopIndexedByAttributeGroupId)){
                        $attributeGroupShopIndexedByMapIds[$attributeGroupParentMappedId] = $attributeGroupMappedId;
                    }
                }
            }
            foreach ($batchToProcess as $attributeGroupMapId => $attributeGroupMapData){
                if (array_key_exists($attributeGroupMapId, $attributeGroupShopIndexedByMapIds)){
                    $version = json_decode($attributeGroupVersionsIndexedByMapIds[$attributeGroupMapId], true);
                    $attributeGroupIndexedByIsoCode = array_column($attributesGroup[$attributeGroupMapId]['AttributeGroupLangs'], 'Version', 'IsoCode');
                    foreach ($version as $isoCode => $codeVersion){
                        if (array_key_exists($attributeGroupMapId, $attributesGroup)
                            && filter_var($codeVersion, FILTER_SANITIZE_NUMBER_INT) > $attributeGroupIndexedByIsoCode[$isoCode]){
                            $processedArray[] = ['shopId' => (int)$attributeGroupShopIndexedByMapIds[$attributeGroupMapId], 'id' => (int)$attributeGroupMapId];
                            continue;
                        }
                    }

                    $attributeGroupMapData->id = $attributeGroupShopIndexedByMapIds[$attributeGroupMapId];
                    $attributeGroupIdsToUpdateIndexedByAttributeGroupMapId[$attributeGroupMapId] = false;
                    $attributeGroupFactoryToUpdate[] = $attributeGroupMapData;
                    $attributeGroupToUpdateIndexedByAttributeGroupMapId[$attributeGroupMapId] = $attributeGroupMapData;
                    continue;
                }
                
                if(!array_key_exists($attributeGroupMapId, $attributeGroupMapsIndexedByAttributeGroupMapId)){
                    $attributeGroupIdsToUpdateIndexedByAttributeGroupMapId[$attributeGroupMapId] = false;
                    $attributeGroupFactorySave[] = $attributeGroupMapData;
                    $attributeGroupToSaveIndexedByAttributeGroupMapId[$attributeGroupMapId] = $attributeGroupMapData;
                    continue;
                }

                $attributeGroupToSaveIndexedByAttributeGroupMapId[$attributeGroupMapId] = $attributeGroupMapData;
                $attributeGroupIdsToUpdateIndexedByAttributeGroupMapId[$attributeGroupMapId] = true;
                $attributeGroupFactorySave[] = $attributeGroupMapData;
            }

            $attributeGroupRequest = ['create' => $attributeGroupFactorySave, 'update' => $attributeGroupFactoryToUpdate];

            $attributeGroupBatchResponse = $this->attributeGroupManager->save($attributeGroupRequest);

            if (array_key_exists('create', $attributeGroupBatchResponse) && $attributeGroupBatchResponse['create']) {
                $processedArray[] =  $this->save($attributeGroupBatchResponse['create'],
                    $attributeGroupToSaveIndexedByAttributeGroupMapId,
                    $attributeGroupIdsToUpdateIndexedByAttributeGroupMapId,
                    $attributesGroup,
                    $fileId
                );
            }

            if (array_key_exists('update', $attributeGroupBatchResponse) && $attributeGroupBatchResponse['update']) {
                $processedArray[] = $this->update($attributeGroupBatchResponse['update'],
                    $attributeGroupToUpdateIndexedByAttributeGroupMapId,
                    $attributesGroup,
                    $fileId
                );
            }
        }

        $processed = array_merge(...$processedArray);

        return array_column($processed, 'shopId', 'id');
    }

    /**
     * @param array $attributeGroupBatchResponse
     * @param array  $attributeGroupIndexedByAttributeGroupMapId
     * @param array  $attributeGroupIdsToUpdateIndexedByAttributeGroupMapId
     * @param array  $attributeGroups
     * @param int    $fileId
     *
     * @return array
     */
    private function save(array $attributeGroupBatchResponse, array $attributeGroupIndexedByAttributeGroupMapId, array $attributeGroupIdsToUpdateIndexedByAttributeGroupMapId, array $attributeGroups, int $fileId): array
    {
        $attributeGroupIds = [];
        $attributeGroupMapIndex = 0;
        $attributesToDelete = null;

        foreach ($attributeGroupIndexedByAttributeGroupMapId as $attributeGroupId => $attributeGroupMapData){
            $attributeGroup = $attributeGroupBatchResponse[$attributeGroupMapIndex];
            $attributeGroupMapIndex++;
            $attributeUpdated = true;
            $attributeSaved = true;

            if(!$attributeGroup){
                continue;
            }

            if(array_key_exists('error', $attributeGroup) && $attributeGroup['error']){
                $importProcess = $this->importProcessService->setFailure($attributeGroupId, $fileId);
                $this->logger->getInstance()->error('AttributeGroupID: '.$attributeGroupId.' in the FileID: '.$fileId.' has been not created. Batch response: '
                    .$attributeGroup['error']['message'].'. AttributeGroup object: '.json_encode($attributeGroupMapData, true). 'ImportProcess mapped: '.$importProcess);
                continue;
            }

            $attributeGroupToMap = $this->attributeGroupMapFactory->create($attributeGroups[$attributeGroupId], $attributeGroup['id'], $this->languages);

            if(array_key_exists($attributeGroupId, $attributeGroupIdsToUpdateIndexedByAttributeGroupMapId) && $attributeGroupIdsToUpdateIndexedByAttributeGroupMapId[$attributeGroupId]){
                $attributeUpdated = $this->attributeGroupMapManager->update($attributeGroup['id'], $attributeGroupToMap);
            }else{
                $attributeSaved = $this->attributeGroupMapManager->save($attributeGroupToMap);
            }

            $importProcess = $this->importProcessService->setSuccess($attributeGroupId, $fileId);
            if (!$attributeUpdated){
                $this->logger->getInstance()->error('AttributeGroupID: '.$attributeGroupId.' in the FileID: '.$fileId.' has been not update his map. AttributeGroup object: '
                    .json_encode($attributeGroupToMap, true). ' with ShopID: '.$attributeGroup['id']. 'ImportProcess Saved: '.$importProcess);
            }

            if (!$attributeSaved){
                $attributesToDelete[$attributeGroupId] = $attributeGroupToMap->shopAttributeGroupId;
                $this->logger->getInstance()->error('AttributeGroupID: '.$attributeGroupId.' in the FileID: '.$fileId.' has been not mapped. AttributeGroup object: '
                    .json_encode($attributeGroupToMap, true). '. ImportProcess Saved: '.$importProcess);
                continue;
            }

            $attributeGroupIds[] = ['shopId' => $attributeGroup['id'], 'id' => $attributeGroupId];
        }

        if ($attributesToDelete){
            $attributeGroupRequest = ['delete' => array_values($attributesToDelete)];
            $this->attributeGroupManager->save($attributeGroupRequest);
            $this->logger->getInstance()->error('AttributeGroupIDs: '.json_encode(array_keys($attributesToDelete), true).' in the FileID: '
                .$fileId.' have been deleted.');
        }

        return $attributeGroupIds;
    }

    /**
     * @param array $attributeGroupBatchResponse
     * @param array $attributeGroupIndexedByAttributeGroupMapId
     * @param array $attributeGroups
     * @param int   $fileId
     *
     * @return array
     */
    private function update(array $attributeGroupBatchResponse, array $attributeGroupIndexedByAttributeGroupMapId, array $attributeGroups, int $fileId): array
    {
        $attributeGroupIds = [];
        $attributeGroupMapIndex = 0;

        foreach ($attributeGroupIndexedByAttributeGroupMapId as $attributeGroupId => $attributeGroupMapData){
            $attributeGroup = $attributeGroupBatchResponse[$attributeGroupMapIndex];
            $attributeGroupMapIndex++;

            if(!$attributeGroup){
                continue;
            }

            if(array_key_exists('error', $attributeGroup) && $attributeGroup['error']){
                $importProcess = $this->importProcessService->setFailure($attributeGroupId, $fileId);
                $this->logger->getInstance()->error('AttributeGroupID: '.$attributeGroupId.' in the FileID: '.$fileId.' has been not updated. Batch response: '
                    .$attributeGroup['error']['message'].'. AttributeGroup object: '.json_encode($attributeGroupMapData, true). 'ImportProcess mapped: '.$importProcess);
                continue;
            }

            $attributeGroupToMap = $this->attributeGroupMapFactory->create($attributeGroups[$attributeGroupId], $attributeGroup['id'], $this->languages);

            $attributeUpdated = $this->attributeGroupMapManager->update($attributeGroup['id'], $attributeGroupToMap);
            $importProcess = $this->importProcessService->setSuccess($attributeGroupId, $fileId);
            if (!$attributeUpdated){
                $this->logger->getInstance()->error('AttributeGroupID: '.$attributeGroupId.' in the FileID: '.$fileId.' has been not update his map. AttributeGroup object: '
                    .json_encode($attributeGroupToMap, true). ' with ShopID: '.$attributeGroup['id']. 'ImportProcess Saved: '.$importProcess);
            }

            $attributeGroupIds[] = ['shopId' => $attributeGroup['id'], 'id' => $attributeGroupId];
        }

        return $attributeGroupIds;
    }
}