<?php

namespace WcMipConnector\Service;

defined('ABSPATH') || exit;

use WcMipConnector\Exception\WooCommerceApiConnectionException;
use WcMipConnector\Factory\CategoryMapFactory;
use WcMipConnector\Factory\CategoryFactory;
use WcMipConnector\Manager\CategoryManager;
use WcMipConnector\Manager\CategoryMapManager;
use WcMipConnector\Manager\ImportProcessCategoryManager;

class CategoryService
{
    /** @var CategoryFactory  */
    protected $categoryFactory;
    /** @var CategoryMapFactory  */
    protected $categoryMapFactory;
    /** @var CategoryMapManager  */
    protected $categoryMapManager;
    /** @var CategoryManager  */
    protected $categoryManager;
    /** @var ImportProcessCategoryService  */
    protected $importProcessService;
    /** @var LoggerService  */
    protected $logger;
    /** @var array */
    protected $languages;
    /** @var ImportProcessCategoryManager  */
    protected $importProcessManager;
    /** @var SystemService */
    protected $systemService;

    public function __construct()
    {
        $this->categoryFactory = new CategoryFactory();
        $this->categoryMapFactory = new CategoryMapFactory();
        $this->categoryMapManager = new CategoryMapManager();
        $this->categoryManager = new CategoryManager();
        $this->importProcessService = new ImportProcessCategoryService();
        $this->importProcessManager = new ImportProcessCategoryManager();
        $loggerService = new LoggerService();
        $this->logger = $loggerService->getInstance();
        $this->systemService = new SystemService();
    }

    /**
     * @param array $categories
     * @param int|null $fileId
     * @param array $languages
     * @return array
     */
    public function processByBatch(array $categories, int $fileId = null, array $languages): array
    {
        $this->languages = $languages;
        $categoriesShopIndexedByCategoryId = [];
        $categoriesCreated = [[]];
        $categoriesUpdated = [[]];
        $categoriesIgnored = [[]];
        $mappedCategoriesShopIdsIndexedByCategoryId = [];
        $categoriesProcessedArray = [[]];
        $categoryOverrideTitleIndexedByCategoryId = [];
        $batches = array_chunk($categories, $this->systemService->getBatchValue(), true);

        foreach ($batches as $categoriesToProcess) {
            $categoryIdsToUpdateIndexedByCategoryMapId = [];
            $categoriesToSaveIndexedByCategoryMapId = [];
            $categoriesToUpdateIndexedByCategoryMapId = [];
            $categoriesShopIdsIndexedByCategoryMapId = $this->categoryMapManager->findAllIndexedByCategoryMapId(array_keys($categoriesToProcess));
            $categoriesVersionsIndexedById = $this->categoryMapManager->findVersionIndexedByCategoryMapId(array_keys($categoriesShopIdsIndexedByCategoryMapId));

            if(!empty($categoriesShopIdsIndexedByCategoryMapId)) {
                $categoriesShopIndexedByCategoryId = $this->categoryManager->findByCategoryShopIdsIndexedByCategoryId(array_values($categoriesShopIdsIndexedByCategoryMapId));
            }

            if($categoriesShopIndexedByCategoryId){
                foreach ($categoriesShopIdsIndexedByCategoryMapId as $categoryParentMapped => $categoryMapped){
                    if(array_key_exists($categoryMapped, $categoriesShopIndexedByCategoryId)){
                        $mappedCategoriesShopIdsIndexedByCategoryId[$categoryParentMapped] = $categoryMapped;
                    }
                }
            }

            $categoryFactorySave = [];
            $categoryFactoryToUpdate = [];
            $categoryFactoryDelete = [];
            $categoriesToDeleteIndexedByShopId = [];

            foreach ($categoriesToProcess as $categoryData) {
                if ($categoryData === null) {
                    continue;
                }

                $categoryParentId = 0;
                $categoryMapId = $categoryData['CategoryID'];

                if (array_key_exists('Active', $categoryData) &&
                    !$categoryData['Active'] && !array_key_exists($categoryMapId, $mappedCategoriesShopIdsIndexedByCategoryId)) {
                    continue;
                }

                if (array_key_exists('Active', $categoryData) &&
                    !$categoryData['Active'] && array_key_exists($categoryMapId, $mappedCategoriesShopIdsIndexedByCategoryId)) {
                    $categoryFactoryDelete[] = (int)$mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryID']];
                    $categoriesToDeleteIndexedByShopId[(int)$mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryID']]] = (int)$categoryData['CategoryID'];
                    continue;
                }

                if (array_key_exists($categoryMapId, $mappedCategoriesShopIdsIndexedByCategoryId)){
                    $version = json_decode($categoriesVersionsIndexedById[$categoryData['CategoryID']], true);
                    if($categoryData['Version'] < $version['version']){
                        $ignoredCategories[] = ['shopId' => (int)$mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryID']], 'id' => (int)$categoryData['CategoryID']];
                        $categoriesProcessedArray[] = $ignoredCategories;
                        $categoriesIgnored[] = $ignoredCategories;
                        continue;
                    }

                    if(array_key_exists('OverrideCategoryTree', $categoryData)
                        && $categoryData['OverrideCategoryTree']
                        && array_key_exists($categoryData['CategoryParentID'], $mappedCategoriesShopIdsIndexedByCategoryId)
                        && $mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryParentID']]){
                        $categoryParentId = $mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryParentID']];
                    }

                    $categoryMapData = $this->categoryFactory->create($categoryData, $categoryData['OverrideCategoryTree'], $categoryParentId, $languages);

                    foreach ($categoryData['CategoryLangs'] as $key => $categoryLang) {
                        if(array_key_exists($categoryLang['IsoCode'], $version) && $categoryLang['Version'] < $version[$categoryLang['IsoCode']]) {
                            unset($categoryMapData->name, $categoryMapData->slug);
                            $categoryData['CategoryLangs'][$key]['Version'] = $version[$categoryLang['IsoCode']];
                            continue;
                        }

                        if (array_key_exists($categoryLang['IsoCode'], $version)) {
                            $categoryOverrideTitleIndexedByCategoryId[$categoryMapId] = $categoryLang['OverrideTitle'];
                            continue;
                        }
                    }

                    if(array_key_exists($categoryMapId, $categoryOverrideTitleIndexedByCategoryId) && !$categoryOverrideTitleIndexedByCategoryId[$categoryMapId]) {
                        unset($categoryMapData->name, $categoryMapData->slug);
                    }

                    $categoryMapData->id = $categoriesShopIdsIndexedByCategoryMapId[$categoryMapId];
                    $categoryIdsToUpdateIndexedByCategoryMapId[$categoryMapId] = false;
                    $categoryFactoryToUpdate[] = $categoryMapData;
                    $categoriesToUpdateIndexedByCategoryMapId[$categoryMapId] = $categoryMapData;
                    continue;
                }

                if (!array_key_exists($categoryMapId, $categoriesShopIdsIndexedByCategoryMapId)) {
                    if (array_key_exists('CategoryParentID', $categoryData) &&
                        array_key_exists($categoryData['CategoryParentID'], $mappedCategoriesShopIdsIndexedByCategoryId) &&
                        $mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryParentID']]){
                        $categoryParentId = $mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryParentID']];
                    }

                    $categoryMapData = $this->categoryFactory->create($categoryData,true, $categoryParentId, $languages);
                    $categoryIdsToUpdateIndexedByCategoryMapId[$categoryMapId] = false;
                    $categoryFactorySave[] = $categoryMapData;
                    $categoriesToSaveIndexedByCategoryMapId[$categoryMapId] = $categoryMapData;
                    continue;
                }

                if (array_key_exists($categoryData['CategoryParentID'], $mappedCategoriesShopIdsIndexedByCategoryId)
                    && $mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryParentID']]){
                    $categoryParentId = $mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryParentID']];
                }

                $categoryMapData = $this->categoryFactory->create($categoryData,true, $categoryParentId, $languages);
                $categoriesToSaveIndexedByCategoryMapId[$categoryMapId] = $categoryMapData;
                $categoryIdsToUpdateIndexedByCategoryMapId[$categoryMapId] = true;
                $categoryFactorySave[] = $categoryMapData;
            }

            $categoryRequest = ['create' => $categoryFactorySave, 'update' => $categoryFactoryToUpdate, 'delete' => $categoryFactoryDelete];

            try {
                $categoriesBatchResponse = $this->categoryManager->save($categoryRequest);
            } catch (WooCommerceApiConnectionException $exception) {
                $this->logger->error('Category Batch - Exception Message: '.$exception->getMessage());
                continue;
            }

            if(array_key_exists('create', $categoriesBatchResponse) && $categoriesBatchResponse['create']) {
                $createdCategories =  $this->save($categoriesBatchResponse['create'], $categoriesToSaveIndexedByCategoryMapId, $categoryIdsToUpdateIndexedByCategoryMapId, $categoriesToProcess, $fileId);
                $categoriesProcessedArray[] = $createdCategories;
                $categoriesCreated[] = $createdCategories;
            }

            if (array_key_exists('update', $categoriesBatchResponse) && $categoriesBatchResponse['update']) {
                $updatedCategories = $this->update($categoriesBatchResponse['update'], $categoriesToUpdateIndexedByCategoryMapId, $categoriesToProcess, $fileId);
                $categoriesProcessedArray[] = $updatedCategories;
                $categoriesUpdated[] = $updatedCategories;
            }

            if (array_key_exists('delete', $categoriesBatchResponse) && $categoriesBatchResponse['delete']) {
                $this->delete($categoriesBatchResponse['delete'], $categoriesToDeleteIndexedByShopId);
            }
        }

        if ($categoriesUpdated) {
            $categoriesUpdated = array_merge(...$categoriesUpdated);
        }

        if ($categoriesIgnored) {
            $categoriesIgnored = array_merge(...$categoriesIgnored);
        }

        if ($categoriesCreated){
            $categoriesCreated = array_merge(...$categoriesCreated);
            $this->setParents($categories, $categoriesCreated, $categoriesUpdated, $categoriesIgnored);
        }

        $categoriesProcessed = array_merge(...$categoriesProcessedArray);
        return array_column($categoriesProcessed, 'shopId', 'id');
    }

    private function setParents(array $categoriesToProcess, array $categoriesCreated = null, array $categoriesUpdated = null, array $categoriesIgnored = null): void
    {
        $categoryToSetParent = [];
        $categoriesToUpdateParent = array_merge($categoriesUpdated, $categoriesIgnored);
        $categoriesToUpdateParentIndexedById = array_column($categoriesToUpdateParent,'shopId','id');
        $mappedCategories = array_merge($categoriesCreated, $categoriesUpdated, $categoriesIgnored);
        $mappedCategoriesShopIdsIndexedByCategoryId = array_column($mappedCategories, 'shopId', 'id');
        $categoriesCreatedIndexedById = array_column($categoriesCreated, 'shopId', 'id');
        $parentShopIdsIndexedByShopId = $this->categoryManager->findParentsShopIdsIndexedByShopId(array_values($mappedCategoriesShopIdsIndexedByCategoryId));

        foreach ($mappedCategoriesShopIdsIndexedByCategoryId as $mappedCategoryId => $mappedCategoryShopIdIndexedByCategoryId) {
            $categoryData = $categoriesToProcess[$mappedCategoryId];
            if (array_key_exists('CategoryID', $categoryData) && array_key_exists('CategoryParentID', $categoryData) &&
                array_key_exists($categoryData['CategoryID'], $categoriesCreatedIndexedById) &&
                array_key_exists($categoryData['CategoryParentID'], $mappedCategoriesShopIdsIndexedByCategoryId) &&
                (int)$parentShopIdsIndexedByShopId[$mappedCategoryShopIdIndexedByCategoryId] !==
                $mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryParentID']]) {
                $categoryToSetParent[] = [
                    'id' => $mappedCategoryShopIdIndexedByCategoryId,
                    'parent' => $mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryParentID']]
                ];
            }

            if (array_key_exists('OverrideCategoryTree', $categoryData) &&
                $categoryData['OverrideCategoryTree'] && array_key_exists($categoryData['CategoryID'], $categoriesToUpdateParentIndexedById)
                && array_key_exists('CategoryParentID', $categoryData)
                && array_key_exists($categoryData['CategoryParentID'], $mappedCategoriesShopIdsIndexedByCategoryId)) {
                $categoryToSetParent[] = [
                    'id' => $mappedCategoryShopIdIndexedByCategoryId,
                    'parent' => $mappedCategoriesShopIdsIndexedByCategoryId[$categoryData['CategoryParentID']]
                ];
            }
        }

        $batches = array_chunk($categoryToSetParent, $this->systemService->getBatchValue(), true);

        foreach ($batches as $categorySetParent) {
            $categoryRequest = ['update' => $categorySetParent];
            try {
                $this->categoryManager->save($categoryRequest);
            } catch (WooCommerceApiConnectionException $exception) {
                $this->logger->error('Category SetParents - Exception Message: '.$exception->getMessage());
            }
        }
    }

    /**
     * @param array $categoriesBatchResponse
     * @param array $categoriesToDeleteIndexedByShopId
     */
    private function delete(array $categoriesBatchResponse, array $categoriesToDeleteIndexedByShopId): void
    {
        $categoryIds = [];
        foreach ($categoriesBatchResponse as $categoryDelete) {
            if (array_key_exists($categoryDelete['id'], $categoriesToDeleteIndexedByShopId)) {
                $categoryIds[] = $categoriesToDeleteIndexedByShopId[$categoryDelete['id']];
            }
        }

        $this->categoryMapManager->deleteByCategoryIds($categoryIds);
        $this->importProcessManager->deleteByCategoryIds($categoryIds);
    }

    /**
     * @param array $categoriesBatchResponse
     * @param array  $categoriesIndexedByCategoryMapId
     * @param array  $categoryIdsToUpdateIndexedByCategoryMapId
     * @param array  $categories
     * @param int|null  $fileId
     *
     * @return array
     */
    private function save(array $categoriesBatchResponse, array $categoriesIndexedByCategoryMapId, array $categoryIdsToUpdateIndexedByCategoryMapId, array $categories, int $fileId = null): array
    {
        $categoryIds = [];
        $categoryMapIndex = 0;
        $importProcess = false;
        $categoriesToDelete = null;
        $categoryBatchResponse = [];

        foreach ($categoriesIndexedByCategoryMapId as $categoryId => $categoryMapData) {
            $category = $categoriesBatchResponse[$categoryMapIndex];
            $categoryMapIndex++;

            if(!$category) {
                continue;
            }

            if(array_key_exists('error', $category) && $category['error']) {
                if($fileId) {
                    $importProcess = $this->importProcessService->setFailure($categoryId, $fileId);
                    $this->logger->error(' Save Category Id: '.$categoryId.' of file Id: '.$fileId.' - Batch Error Message: '
                        . $category['error']['message'].' - Category object: '.json_encode($categoryMapData, true).' - SetFailure result: '.$importProcess);
                    continue;
                }
                $this->logger->error(' Save Category Id: '.$categoryId.' by UpdateCategories - Batch Error Message: '
                    . $category['error']['message'].' - Category object: '.json_encode($categoryMapData, true));
                continue;
            }

            $categoryToMap = $this->categoryMapFactory->create($categories[$categoryId], $category['id'], $this->languages);

            if (array_key_exists($categoryId, $categoryIdsToUpdateIndexedByCategoryMapId) && $categoryIdsToUpdateIndexedByCategoryMapId[$categoryId]){
                $mappedResult = $this->categoryMapManager->update($category['id'], $categoryToMap);
            }else {
                $mappedResult = $this->categoryMapManager->save($categoryToMap);
            }

            if($fileId) {
                $importProcess = $this->importProcessService->setSuccess($categoryId, $fileId);
            }

            if (!$mappedResult) {
                $this->logger->error('Map in Save Category Id: '.$categoryId.' in the File Id: '.$fileId.' - Category Shop Id: '.$category['id'].' - Data to map: '.json_encode($categoryToMap, true). ' - SetSuccess result: '.$importProcess);
                $categoriesToDelete[$categoryId] = $categoryToMap->shopCategoryId;
                continue;
            }

            if (!$importProcess) {
                $this->logger->error('SetSuccess in Save Category Id: '.$categoryId.' in the File Id: '.$fileId.' - SetSuccess result: '.$importProcess);
            }

            $categoryIds[] = ['shopId' => $category['id'], 'id' => $categoryId];
        }

        if ($categoriesToDelete){
            $categoryRequest = ['delete' => array_values($categoriesToDelete)];

            try {
                $categoryBatchResponse = $this->categoryManager->save($categoryRequest);
            } catch (WooCommerceApiConnectionException $exception) {
                $this->logger->error('Category Delete - Batch Request: '.json_encode($categoryRequest, true).' - Exception Message: '.$exception->getMessage());
            }

            foreach ($categoryBatchResponse['delete'] as $cat) {
                if ($cat['error']) {
                    $this->logger->error('Delete of shop unmapped category: '. $cat['id'] . ' - Error Message: '.$cat['error']['message']);
                }
            }
        }

        return $categoryIds;
    }

    /**
     * @param array $categoriesBatchResponse
     * @param array $categoriesIndexedByCategoryMapId
     * @param array $categories
     * @param int|null $fileId
     * @return array
     */
    private function update(array $categoriesBatchResponse, array $categoriesIndexedByCategoryMapId, array $categories, int $fileId = null): array
    {
        $categoryIds = [];
        $categoryMapIndex = 0;
        $importProcess = false;

        foreach ($categoriesIndexedByCategoryMapId as $categoryId => $categoryMapData) {
            $category = $categoriesBatchResponse[$categoryMapIndex];
            $categoryMapIndex++;

            if(!$category) {
                continue;
            }

            if(array_key_exists('error', $category) && $category['error']) {
                if($fileId) {
                    $importProcess = $this->importProcessService->setFailure($categoryId, $fileId);
                    $this->logger->error(' Update Category Id: '.$categoryId.' of file Id: '.$fileId.' - Batch Error Message: '
                        . $category['error']['message'].' - Category object: '.json_encode($categoryMapData, true).' - SetFailure result: '.$importProcess);
                    continue;
                }
                $this->logger->error(' Update Category Id: '.$categoryId.' by UpdateCategories - Batch Error Message: '
                    . $category['error']['message'].' - Category object: '.json_encode($categoryMapData, true));
                continue;
            }

            $categoryToMap = $this->categoryMapFactory->create($categories[$categoryId], $category['id'], $this->languages);
            $categoryMapped = $this->categoryMapManager->update($category['id'], $categoryToMap);

            if($fileId) {
                $importProcess = $this->importProcessService->setSuccess($categoryId, $fileId);
            }

            if(!$categoryMapped){
                $this->logger->error('Map in Save Category Id: '.$categoryId.' in the File Id: '.$fileId.' - Category Shop Id: '.$category['id'].' - Data to map: '.json_encode($categoryToMap, true). ' - SetSuccess result: '.$importProcess);
            }

            $categoryIds[] = ['shopId' => $category['id'], 'id' => $categoryId];
        }

        return $categoryIds;
    }

    /**
     * @param array $categories
     * @param array $languages
     * @throws \Exception
     */
    public function updateCategories(array $categories, array $languages): void
    {
        $categoriesIndexedByCategoryId = [];

        if (empty($categories)) {
            return;
        }

        foreach ($categories['Categories'] as $category) {
            if ($category['CategoryParentID'] !== null && !array_key_exists($category['CategoryParentID'], $categoriesIndexedByCategoryId)) {
                $categoriesIndexedByCategoryId[$category['CategoryParentID']] = null;
            }
            $categoriesIndexedByCategoryId[$category['CategoryID']] = $category;
        }

        $this->processByBatch($categoriesIndexedByCategoryId, null, $languages);
    }
}