<?php

namespace WcMipConnector\Service;

defined('ABSPATH') || exit;

use WcMipConnector\Enum\MipWcConnector;
use WcMipConnector\Manager\FileLogManager;

class FileLogService
{
    /** @var FileLogManager */
    protected $manager;
    private $logsDir;
    private $importFilesDir;

    private const MINIMUN_SECONDS_TO_DELETE_FILE = 604800;
    private const MINIMUN_DAYS_TO_DELETE_FILE_LOG  = 7;
    private const VAR_LOG_FOLDER = '/logs';

    public function __construct()
    {
        $this->manager = new FileLogManager();
        $this->logsDir = MipWcConnector::VAR_DIR.self::VAR_LOG_FOLDER;
        $this->importFilesDir = MipWcConnector::VAR_DIR.FileService::IMPORT_FILES_FOLDER;
    }

    /**
     * @param int $minimDaysToDeleteFileLog
     */
    public function checkOldFileLog(int $minimDaysToDeleteFileLog  = self::MINIMUN_DAYS_TO_DELETE_FILE_LOG ): void
    {
        $fileLogs = $this->manager->getFileLogNameByDay($minimDaysToDeleteFileLog);

        if (!$fileLogs) {
            return;
        }

        foreach ($fileLogs as $fileLog) {
            $fileLocation = $this->importFilesDir.'/'.$fileLog['name'].'.json';
            $this->manager->deleteFileLogByFileName($fileLog);

            if (file_exists($fileLocation)) {
                unlink($fileLocation);
            }
        }
    }

    /**
     * @param int $minimunSecondsToDeleteFile
     */
    public function deleteLogsByDay(int $minimunSecondsToDeleteFile = self::MINIMUN_SECONDS_TO_DELETE_FILE): void
    {
        $logs = scandir($this->logsDir);
        $currentTime = time();

        foreach ($logs as $log) {
            if (strpos($log, '.log') && $log !== '.' && $log !== '..') {
                $fileCreationTime = filemtime($this->logsDir.'/'. $log);
                $dateDifference = $currentTime - $fileCreationTime;

                if ($dateDifference >= $minimunSecondsToDeleteFile) {
                    unlink($this->logsDir.'/'. $log);
                }
            }
        }
    }
}