<?php

namespace WcMipConnector\Service;

defined('ABSPATH') || exit;

use Monolog\Handler\RotatingFileHandler;
use Monolog\Logger as MonologLogger;
use WcMipConnector\Enum\MipWcConnector;

/**
 * Class Logger
 *
 * @method emergency($message, $data = [])
 * @method alert($message, $data = [])
 * @method critical($message, $data = [])
 * @method error($message, $data = [])
 * @method warning($message, $data = [])
 * @method notice($message, $data = [])
 * @method info($message, $data = [])
 * @method debug($message, $data = [])
 */
class LoggerService
{
    private const MAX_FILES = 7;
    private const LOG_FILE_EXTENSION = '.log';
    private const LOG_DIR_NAME = '/var/logs/';
    private const LOG_DIR = MipWcConnector::MODULE_DIR . self::LOG_DIR_NAME;
    private const LOG_DATA = 'Logs WcMipConnector';
    private const MASK = 0000;
    private const FILE_LOG_PERMISSIONS = 0775;

    /** @var LoggerService */
    private static $logger;
    /** @var \Psr\Log\LoggerInterface */
    private $appLogger;

    public function __construct()
    {
        $oldPermissions = umask(self::MASK);
        $loggingDir = self::LOG_DIR;

        if (!@mkdir($loggingDir) && !is_dir($loggingDir)) {
            return;
        }

        @chmod($loggingDir, self::FILE_LOG_PERMISSIONS);
        $loggingFileName = $loggingDir . MipWcConnector::LOG_FILE_NAME . self::LOG_FILE_EXTENSION;

        if (!file_exists($loggingFileName)) {
            file_put_contents($loggingFileName, self::LOG_DATA);
            @chmod($loggingFileName, self::FILE_LOG_PERMISSIONS);
        }

        $this->appLogger = new MonologLogger(MipWcConnector::LOG_FILE_NAME);

        $this->appLogger->pushHandler(new RotatingFileHandler($loggingFileName, self::MAX_FILES, MonologLogger::INFO));
        umask($oldPermissions);
    }

    /**
     * @return LoggerService
     */
    public function getInstance(): self
    {
        if (!self::$logger) {
            self::$logger = new self();
        }

        return self::$logger;
    }

    /**
     * @param $levelName
     * @param $arguments
     * @return mixed
     */
    public function __call($levelName, $arguments)
    {
        if (!$this->isValidLevel($levelName)) {
            throw new \InvalidArgumentException($levelName.'logging level is invalid');
        }

        $argumentsCount = count($arguments);

        if (0 === $argumentsCount) {
            throw new \InvalidArgumentException('Logger needs at least a message :'. $argumentsCount);
        }

        $message = $arguments[0];
        $data = [];

        if (2 === $argumentsCount) {
            $data = $arguments[1];

            if (!is_array($data)) {
                $data = [$data];
            }
        }

        return $this->appLogger->{$levelName}($message, $data);
    }

    /**
     * @param string $levelName
     * @return bool
     */
    private function isValidLevel($levelName): bool
    {
        $levels = MonologLogger::getLevels();

        if (!isset($levels[strtoupper($levelName)])) {
            return false;
        }

        return true;
    }
}