<?php

namespace WcMipConnector\Service;

defined('ABSPATH') || exit;

require __DIR__.'/../../vendor/autoload.php';

use Automattic\WooCommerce\Client;
use WcMipConnector\Manager\WoocommerceApiConnectionManager;
use WcMipConnector\Exception\WooCommerceApiConnectionException;
use stdClass;

class WoocommerceApiConnectionService
{
    private const API_VERSION = 'wc/v3';
    private const TIMEOUT = 100000;

    protected $woocommerceApiConnectionManager;
    protected $apiConnection;
    protected $apiClient;
    protected $logger;

    public function __construct()
    {
        $this->woocommerceApiConnectionManager = new WoocommerceApiConnectionManager();
        $loggerService = new LoggerService();
        $this->logger = $loggerService->getInstance();
    }

    /**
     * @return Client
     */
    public function getWoocommerceApiConnection(): Client
    {
        $option = $this->woocommerceApiConnectionManager->getOptionBySiteUrl();
        $consumer = $this->woocommerceApiConnectionManager->getAccessToken();
        $secret = $this->woocommerceApiConnectionManager->getSecretKey();

        $this->apiClient = new Client(
            $option,
            $consumer,
            $secret,
            [
                'wp_api' => true,
                'version' => self::API_VERSION,
                'query_string_auth' => true,
                'timeout' => self::TIMEOUT
            ]
        );

        return $this->apiClient;
    }

    /**
     * @param string $endPoint
     * @param array $data
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function post(string $endPoint, array $data): array
    {
        try {
            $this->apiConnection = $this->getWoocommerceApiConnection();
            return json_decode(json_encode($this->apiConnection->post($endPoint, $data)), true);
        } catch (\Exception $exception) {
            $this->logger->error('Post WooCommerceApiConnection - EndPoint: '.$endPoint.' - Error message: '.$exception->getMessage());
            throw new WooCommerceApiConnectionException('Post WooCommerceApiConnection - EndPoint: '.$endPoint.'- Error message: '.$exception->getMessage());
        }
    }

    /**
     * @param string $endPoint
     * @param array  $data
     *
     * @return stdClass
     */
    public function put(string $endPoint, array $data): stdClass
    {
        $this->apiConnection = $this->getWoocommerceApiConnection();
        return $this->apiConnection->put($endPoint, $data);
    }

    /**
     * @param string $endPoint
     * @param array $parameters
     *
     * @return array
     * @throws WooCommerceApiConnectionException
     */
    public function get(string $endPoint, array $parameters = []): ?array
    {
        try {
            $this->apiConnection = $this->getWoocommerceApiConnection();
            return json_decode(json_encode($this->apiConnection->get($endPoint, $parameters)), true);
        } catch (\Exception $exception) {
            $this->logger->error('Get WooCommerceApiConnection - EndPoint: '.$endPoint.' - Parameters: '.json_encode($parameters).' - Error message: '.$exception->getMessage());
            throw new WooCommerceApiConnectionException('Get WooCommerceApiConnection - EndPoint: '.$endPoint.' - Parameters: '.json_encode($parameters).' - Error message: '.$exception->getMessage());
        }
    }

    /**
     * @param string $endPoint
     * @param array  $parameters
     *
     * @return stdClass
     */
    public function delete(string $endPoint, array $parameters = []): stdClass
    {
        $this->apiConnection = $this->getWoocommerceApiConnection();
        return $this->apiConnection->delete($endPoint, $parameters);
    }
}